# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import BoolPolicy
from pyVmomi.vim import HostSystem
from pyVmomi.vim import InheritablePolicy
from pyVmomi.vim import LongPolicy
from pyVmomi.vim import ManagedEntity
from pyVmomi.vim import NumericRange
from pyVmomi.vim import StringPolicy

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.dvs import KeyedOpaqueBlob
from pyVmomi.vim.dvs import PortConnectee
from pyVmomi.vim.dvs import PortStatistics
from pyVmomi.vim.dvs import TrafficRuleset

class DistributedVirtualPort(DynamicData):
   class ConfigSpec(DynamicData):
      operation: str
      key: Optional[str] = None
      name: Optional[str] = None
      scope: list[ManagedEntity] = []
      description: Optional[str] = None
      setting: Optional[Setting] = None
      configVersion: Optional[str] = None

   class ConfigInfo(DynamicData):
      name: Optional[str] = None
      scope: list[ManagedEntity] = []
      description: Optional[str] = None
      setting: Optional[Setting] = None
      configVersion: str

   class TrafficShapingPolicy(InheritablePolicy):
      enabled: Optional[BoolPolicy] = None
      averageBandwidth: Optional[LongPolicy] = None
      peakBandwidth: Optional[LongPolicy] = None
      burstSize: Optional[LongPolicy] = None

   class HostLocalPortInfo(DynamicData):
      switchUuid: str
      portKey: str
      setting: Setting
      vnic: str

   class VendorSpecificConfig(InheritablePolicy):
      keyValue: list[KeyedOpaqueBlob] = []

   class FilterParameter(DynamicData):
      parameters: list[str] = []

   class FilterOnFailure(Enum):
      failOpen: ClassVar['FilterOnFailure'] = 'failOpen'
      failClosed: ClassVar['FilterOnFailure'] = 'failClosed'

   class FilterConfig(InheritablePolicy):
      key: Optional[str] = None
      agentName: Optional[str] = None
      slotNumber: Optional[str] = None
      parameters: Optional[FilterParameter] = None
      onFailure: Optional[str] = None

   class TrafficFilterConfig(FilterConfig):
      trafficRuleset: Optional[TrafficRuleset] = None

   class FilterConfigSpec(FilterConfig):
      operation: str

   class TrafficFilterConfigSpec(TrafficFilterConfig):
      operation: str

   class FilterPolicy(InheritablePolicy):
      filterConfig: list[FilterConfig] = []

   class Setting(DynamicData):
      blocked: Optional[BoolPolicy] = None
      vmDirectPathGen2Allowed: Optional[BoolPolicy] = None
      inShapingPolicy: Optional[TrafficShapingPolicy] = None
      outShapingPolicy: Optional[TrafficShapingPolicy] = None
      vendorSpecificConfig: Optional[VendorSpecificConfig] = None
      networkResourcePoolKey: Optional[StringPolicy] = None
      filterPolicy: Optional[FilterPolicy] = None

   class RuntimeInfo(DynamicData):
      class VmDirectPathGen2InactiveReasonNetwork(Enum):
         portNptIncompatibleDvs: ClassVar['VmDirectPathGen2InactiveReasonNetwork'] = 'portNptIncompatibleDvs'
         portNptNoCompatibleNics: ClassVar['VmDirectPathGen2InactiveReasonNetwork'] = 'portNptNoCompatibleNics'
         portNptNoVirtualFunctionsAvailable: ClassVar['VmDirectPathGen2InactiveReasonNetwork'] = 'portNptNoVirtualFunctionsAvailable'
         portNptDisabledForPort: ClassVar['VmDirectPathGen2InactiveReasonNetwork'] = 'portNptDisabledForPort'

      class VmDirectPathGen2InactiveReasonOther(Enum):
         portNptIncompatibleHost: ClassVar['VmDirectPathGen2InactiveReasonOther'] = 'portNptIncompatibleHost'
         portNptIncompatibleConnectee: ClassVar['VmDirectPathGen2InactiveReasonOther'] = 'portNptIncompatibleConnectee'

      linkUp: bool
      blocked: bool
      vlanIds: list[NumericRange] = []
      trunkingMode: Optional[bool] = None
      mtu: Optional[int] = None
      linkPeer: Optional[str] = None
      macAddress: Optional[str] = None
      statusDetail: Optional[str] = None
      vmDirectPathGen2Active: Optional[bool] = None
      vmDirectPathGen2InactiveReasonNetwork: list[str] = []
      vmDirectPathGen2InactiveReasonOther: list[str] = []
      vmDirectPathGen2InactiveReasonExtended: Optional[str] = None

   class State(DynamicData):
      runtimeInfo: Optional[RuntimeInfo] = None
      stats: PortStatistics
      vendorSpecificState: list[KeyedOpaqueBlob] = []

   key: str
   config: ConfigInfo
   dvsUuid: str
   portgroupKey: Optional[str] = None
   proxyHost: Optional[HostSystem] = None
   connectee: Optional[PortConnectee] = None
   conflict: bool
   conflictPortKey: Optional[str] = None
   state: Optional[State] = None
   connectionCookie: Optional[int] = None
   lastStatusChange: datetime
   hostLocalPort: Optional[bool] = None
   externalId: Optional[str] = None
   segmentPortId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.ext import ManagedByInfo

from pyVmomi.vim.vApp import EntityConfigInfo
from pyVmomi.vim.vApp import VmConfigSpec

class VAppConfigSpec(VmConfigSpec):
   entityConfig: list[EntityConfigInfo] = []
   annotation: Optional[str] = None
   instanceUuid: Optional[str] = None
   managedBy: Optional[ManagedByInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import FeatureRequirement

class DeviceRuntimeInfo(DynamicData):
   class DeviceRuntimeState(DynamicData):
      pass

   class VirtualEthernetCardRuntimeState(DeviceRuntimeState):
      class VmDirectPathGen2InactiveReasonVm(Enum):
         vmNptIncompatibleGuest: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptIncompatibleGuest'
         vmNptIncompatibleGuestDriver: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptIncompatibleGuestDriver'
         vmNptIncompatibleAdapterType: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptIncompatibleAdapterType'
         vmNptDisabledOrDisconnectedAdapter: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptDisabledOrDisconnectedAdapter'
         vmNptIncompatibleAdapterFeatures: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptIncompatibleAdapterFeatures'
         vmNptIncompatibleBackingType: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptIncompatibleBackingType'
         vmNptInsufficientMemoryReservation: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptInsufficientMemoryReservation'
         vmNptFaultToleranceOrRecordReplayConfigured: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptFaultToleranceOrRecordReplayConfigured'
         vmNptConflictingIOChainConfigured: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptConflictingIOChainConfigured'
         vmNptMonitorBlocks: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptMonitorBlocks'
         vmNptConflictingOperationInProgress: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptConflictingOperationInProgress'
         vmNptRuntimeError: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptRuntimeError'
         vmNptOutOfIntrVector: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptOutOfIntrVector'
         vmNptVMCIActive: ClassVar['VmDirectPathGen2InactiveReasonVm'] = 'vmNptVMCIActive'

      class VmDirectPathGen2InactiveReasonOther(Enum):
         vmNptIncompatibleHost: ClassVar['VmDirectPathGen2InactiveReasonOther'] = 'vmNptIncompatibleHost'
         vmNptIncompatibleNetwork: ClassVar['VmDirectPathGen2InactiveReasonOther'] = 'vmNptIncompatibleNetwork'

      vmDirectPathGen2Active: Optional[bool] = None
      vmDirectPathGen2InactiveReasonVm: list[str] = []
      vmDirectPathGen2InactiveReasonOther: list[str] = []
      vmDirectPathGen2InactiveReasonExtended: Optional[str] = None
      uptv2Active: Optional[bool] = None
      uptv2InactiveReasonVm: list[str] = []
      uptv2InactiveReasonOther: list[str] = []
      reservationStatus: Optional[str] = None
      attachmentStatus: Optional[str] = None
      featureRequirement: list[FeatureRequirement] = []

   runtimeState: DeviceRuntimeState
   key: int



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import FaultToleranceMetaSpec
from pyVmomi.vim.vm import FaultToleranceVMConfigSpec

class FaultToleranceConfigSpec(DynamicData):
   metaDataPath: Optional[FaultToleranceMetaSpec] = None
   secondaryVmSpec: Optional[FaultToleranceVMConfigSpec] = None
   metroFtEnabled: Optional[bool] = None
   metroFtHostGroup: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AgencyDisabled import AgencyDisabled as AgencyDisabled
from .AgencyIssue import AgencyIssue as AgencyIssue
from .AgentIssue import AgentIssue as AgentIssue
from .CannotAccessAgentOVF import CannotAccessAgentOVF as CannotAccessAgentOVF
from .CannotAccessAgentVib import CannotAccessAgentVib as CannotAccessAgentVib
from .CertificateNotTrusted import CertificateNotTrusted as CertificateNotTrusted
from .ExtensibleIssue import ExtensibleIssue as ExtensibleIssue
from .HostInMaintenanceMode import HostInMaintenanceMode as HostInMaintenanceMode
from .HostInPartialMaintenanceMode import HostInPartialMaintenanceMode as HostInPartialMaintenanceMode
from .HostInStandbyMode import HostInStandbyMode as HostInStandbyMode
from .HostIssue import HostIssue as HostIssue
from .HostNotReachable import HostNotReachable as HostNotReachable
from .HostPoweredOff import HostPoweredOff as HostPoweredOff
from .ImmediateHostRebootRequired import ImmediateHostRebootRequired as ImmediateHostRebootRequired
from .IncompatibleHostVersion import IncompatibleHostVersion as IncompatibleHostVersion
from .InsufficientIpAddresses import InsufficientIpAddresses as InsufficientIpAddresses
from .InsufficientResources import InsufficientResources as InsufficientResources
from .InsufficientSpace import InsufficientSpace as InsufficientSpace
from .InvalidConfig import InvalidConfig as InvalidConfig
from .Issue import Issue as Issue
from .MissingAgentIpPool import MissingAgentIpPool as MissingAgentIpPool
from .MissingDvFilterSwitch import MissingDvFilterSwitch as MissingDvFilterSwitch
from .NoAgentVmDatastore import NoAgentVmDatastore as NoAgentVmDatastore
from .NoAgentVmNetwork import NoAgentVmNetwork as NoAgentVmNetwork
from .NoCustomAgentVmDatastore import NoCustomAgentVmDatastore as NoCustomAgentVmDatastore
from .NoCustomAgentVmNetwork import NoCustomAgentVmNetwork as NoCustomAgentVmNetwork
from .NoDiscoverableAgentVmDatastore import NoDiscoverableAgentVmDatastore as NoDiscoverableAgentVmDatastore
from .NoDiscoverableAgentVmNetwork import NoDiscoverableAgentVmNetwork as NoDiscoverableAgentVmNetwork
from .OrphanedAgency import OrphanedAgency as OrphanedAgency
from .OrphanedDvFilterSwitch import OrphanedDvFilterSwitch as OrphanedDvFilterSwitch
from .OvfInvalidFormat import OvfInvalidFormat as OvfInvalidFormat
from .OvfInvalidProperty import OvfInvalidProperty as OvfInvalidProperty
from .TransitionFailed import TransitionFailed as TransitionFailed
from .UnknownAgentVm import UnknownAgentVm as UnknownAgentVm
from .VibCannotPutHostInMaintenanceMode import VibCannotPutHostInMaintenanceMode as VibCannotPutHostInMaintenanceMode
from .VibCannotPutHostOutOfMaintenanceMode import VibCannotPutHostOutOfMaintenanceMode as VibCannotPutHostOutOfMaintenanceMode
from .VibDependenciesNotMetByHost import VibDependenciesNotMetByHost as VibDependenciesNotMetByHost
from .VibInvalidFormat import VibInvalidFormat as VibInvalidFormat
from .VibIssue import VibIssue as VibIssue
from .VibNotInstalled import VibNotInstalled as VibNotInstalled
from .VibRequirementsNotMetByHost import VibRequirementsNotMetByHost as VibRequirementsNotMetByHost
from .VibRequiresHostInMaintenanceMode import VibRequiresHostInMaintenanceMode as VibRequiresHostInMaintenanceMode
from .VibRequiresHostReboot import VibRequiresHostReboot as VibRequiresHostReboot
from .VibRequiresManualInstallation import VibRequiresManualInstallation as VibRequiresManualInstallation
from .VibRequiresManualUninstallation import VibRequiresManualUninstallation as VibRequiresManualUninstallation
from .VmCorrupted import VmCorrupted as VmCorrupted
from .VmDeployed import VmDeployed as VmDeployed
from .VmHookFailed import VmHookFailed as VmHookFailed
from .VmHookTimedout import VmHookTimedout as VmHookTimedout
from .VmInaccessible import VmInaccessible as VmInaccessible
from .VmIssue import VmIssue as VmIssue
from .VmMarkedAsTemplate import VmMarkedAsTemplate as VmMarkedAsTemplate
from .VmNotDeployed import VmNotDeployed as VmNotDeployed
from .VmOrphaned import VmOrphaned as VmOrphaned
from .VmPoweredOff import VmPoweredOff as VmPoweredOff
from .VmPoweredOn import VmPoweredOn as VmPoweredOn
from .VmProtected import VmProtected as VmProtected
from .VmRequiresHostOutOfMaintenanceMode import VmRequiresHostOutOfMaintenanceMode as VmRequiresHostOutOfMaintenanceMode
from .VmSuspended import VmSuspended as VmSuspended
from .VmWrongFolder import VmWrongFolder as VmWrongFolder
from .VmWrongResourcePool import VmWrongResourcePool as VmWrongResourcePool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.vim import ExtensibleManagedObject
from pyVmomi.vim import TaskInfo

from pyVmomi.vmodl import LocalizableMessage
from pyVmomi.vmodl import MethodFault

class Task(ExtensibleManagedObject):
   @property
   def info(self) -> TaskInfo: ...

   def Cancel(self) -> NoReturn: ...
   def UpdateProgress(self, percentDone: int) -> NoReturn: ...
   def SetState(self, state: TaskInfo.State, result: Optional[object], fault: Optional[MethodFault]) -> NoReturn: ...
   def UpdateDescription(self, description: LocalizableMessage) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.storageDrs import VirtualDiskAntiAffinityRuleSpec
from pyVmomi.vim.storageDrs import VirtualDiskRuleSpec

class VmConfigInfo(DynamicData):
   vm: Optional[VirtualMachine] = None
   enabled: Optional[bool] = None
   behavior: Optional[str] = None
   intraVmAffinity: Optional[bool] = None
   intraVmAntiAffinity: Optional[VirtualDiskAntiAffinityRuleSpec] = None
   virtualDiskRules: list[VirtualDiskRuleSpec] = []



# Copyright (c) 2008-2024 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.

allowGetSet = False
allowCapitalizedNames = False
binaryIsBytearray = True



# Copyright (c) 2005-2025 Broadcom. All Rights Reserved.
# The term "Broadcom" refers to Broadcom Inc. and/or its subsidiaries.


def load_typeinfos():
    try:
        from . import _typeinfo_core
    except ImportError:
        pass

    try:
        from . import _typeinfo_eam
    except ImportError:
        pass

    try:
        from . import _typeinfo_pbm
    except ImportError:
        pass

    try:
        from . import _typeinfo_query
    except ImportError:
        pass

    try:
        from . import _typeinfo_sms
    except ImportError:
        pass

    try:
        from . import _typeinfo_vim
    except ImportError:
        pass

    try:
        from . import _typeinfo_vslm
    except ImportError:
        pass

    from .VmomiSupport import SetFreezeDefinitions  # noqa: E402
    try:
        SetFreezeDefinitions(True)
        from . import _typeinfo_vsanhealth
    except ImportError:
        pass
    finally:
        SetFreezeDefinitions(False)



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.pbm.capability import CapabilityInstance

from pyVmomi.pbm.profile import CapabilityConstraints

class SubProfileCapabilityConstraints(CapabilityConstraints):
   class SubProfile(DynamicData):
      name: str
      capability: list[CapabilityInstance] = []
      forceProvision: Optional[bool] = None

   subProfiles: list[SubProfile] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanObjectSpaceSummary

from pyVmomi.vim.vsan import DataEfficiencyCapacityState

class VsanEntitySpaceUsage(DynamicData):
   entityId: Optional[str] = None
   spaceUsageByObjectType: list[VsanObjectSpaceSummary] = []
   totalCapacityB: Optional[long] = None
   freeCapacityB: Optional[long] = None
   efficientCapacity: Optional[DataEfficiencyCapacityState] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class SoftwarePackage(DynamicData):
   class VibType(Enum):
      bootbank: ClassVar['VibType'] = 'bootbank'
      tools: ClassVar['VibType'] = 'tools'
      meta: ClassVar['VibType'] = 'meta'

   class Capability(DynamicData):
      liveInstallAllowed: Optional[bool] = None
      liveRemoveAllowed: Optional[bool] = None
      statelessReady: Optional[bool] = None
      overlay: Optional[bool] = None

   class Constraint(Enum):
      equals: ClassVar['Constraint'] = 'equals'
      lessThan: ClassVar['Constraint'] = 'lessThan'
      lessThanEqual: ClassVar['Constraint'] = 'lessThanEqual'
      greaterThanEqual: ClassVar['Constraint'] = 'greaterThanEqual'
      greaterThan: ClassVar['Constraint'] = 'greaterThan'

   class Relation(DynamicData):
      constraint: Optional[str] = None
      name: str
      version: Optional[str] = None

   name: str
   version: str
   type: str
   vendor: str
   acceptanceLevel: str
   summary: str
   description: str
   referenceURL: list[str] = []
   creationDate: Optional[datetime] = None
   depends: list[Relation] = []
   conflicts: list[Relation] = []
   replaces: list[Relation] = []
   provides: list[str] = []
   maintenanceModeRequired: Optional[bool] = None
   hardwarePlatformsRequired: list[str] = []
   capability: Capability
   tag: list[str] = []
   payload: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ManagedEntity

class TenantManager(ManagedObject):
   def MarkServiceProviderEntities(self, entity: list[ManagedEntity]) -> NoReturn: ...
   def UnmarkServiceProviderEntities(self, entity: list[ManagedEntity]) -> NoReturn: ...
   def RetrieveServiceProviderEntities(self) -> list[ManagedEntity]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.option import BoolOption
from pyVmomi.vim.option import ChoiceOption

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualEthernetCardOption(VirtualDeviceOption):
   class NetworkBackingOption(VirtualDeviceOption.DeviceBackingOption):
      pass

   class OpaqueNetworkBackingOption(VirtualDeviceOption.BackingOption):
      pass

   class LegacyNetworkBackingOption(VirtualDeviceOption.DeviceBackingOption):
      class LegacyNetworkDeviceName(Enum):
         bridged: ClassVar['LegacyNetworkDeviceName'] = 'bridged'
         nat: ClassVar['LegacyNetworkDeviceName'] = 'nat'
         hostonly: ClassVar['LegacyNetworkDeviceName'] = 'hostonly'

   class DistributedVirtualPortBackingOption(VirtualDeviceOption.BackingOption):
      pass

   class MacTypes(Enum):
      manual: ClassVar['MacTypes'] = 'manual'
      generated: ClassVar['MacTypes'] = 'generated'
      assigned: ClassVar['MacTypes'] = 'assigned'

   supportedOUI: ChoiceOption
   macType: ChoiceOption
   wakeOnLanEnabled: BoolOption
   vmDirectPathGen2Supported: Optional[bool] = None
   uptCompatibilityEnabled: Optional[BoolOption] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import Datastore

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasAdmissionControlPolicy
from pyVmomi.vim.cluster import DasVmSettings

from pyVmomi.vim.option import OptionValue

class DasConfigInfo(DynamicData):
   class ServiceState(Enum):
      disabled: ClassVar['ServiceState'] = 'disabled'
      enabled: ClassVar['ServiceState'] = 'enabled'

   class VmMonitoringState(Enum):
      vmMonitoringDisabled: ClassVar['VmMonitoringState'] = 'vmMonitoringDisabled'
      vmMonitoringOnly: ClassVar['VmMonitoringState'] = 'vmMonitoringOnly'
      vmAndAppMonitoring: ClassVar['VmMonitoringState'] = 'vmAndAppMonitoring'

   class HBDatastoreCandidate(Enum):
      userSelectedDs: ClassVar['HBDatastoreCandidate'] = 'userSelectedDs'
      allFeasibleDs: ClassVar['HBDatastoreCandidate'] = 'allFeasibleDs'
      allFeasibleDsWithUserPreference: ClassVar['HBDatastoreCandidate'] = 'allFeasibleDsWithUserPreference'

   enabled: Optional[bool] = None
   vmMonitoring: Optional[str] = None
   hostMonitoring: Optional[str] = None
   vmComponentProtecting: Optional[str] = None
   failoverLevel: Optional[int] = None
   admissionControlPolicy: Optional[DasAdmissionControlPolicy] = None
   admissionControlEnabled: Optional[bool] = None
   defaultVmSettings: Optional[DasVmSettings] = None
   option: list[OptionValue] = []
   heartbeatDatastore: list[Datastore] = []
   hBDatastoreCandidatePolicy: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cns import BackingObjectDetails
from pyVmomi.vim.cns import VolumeId
from pyVmomi.vim.cns import VolumeMetadata

class Volume(DynamicData):
   volumeId: VolumeId
   datastoreUrl: Optional[str] = None
   name: Optional[str] = None
   volumeType: Optional[str] = None
   storagePolicyId: Optional[str] = None
   metadata: Optional[VolumeMetadata] = None
   backingObjectDetails: Optional[BackingObjectDetails] = None
   complianceStatus: Optional[str] = None
   datastoreAccessibilityStatus: Optional[str] = None
   healthStatus: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AlreadyDone import AlreadyDone as AlreadyDone
from .InvalidFunctionTarget import InvalidFunctionTarget as InvalidFunctionTarget
from .InvalidReplicationState import InvalidReplicationState as InvalidReplicationState
from .NoReplicationTarget import NoReplicationTarget as NoReplicationTarget
from .NoValidReplica import NoValidReplica as NoValidReplica
from .PeerNotReachable import PeerNotReachable as PeerNotReachable
from .ReplicationFault import ReplicationFault as ReplicationFault
from .SyncOngoing import SyncOngoing as SyncOngoing



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.event import GeneralEvent

class ExtendedEvent(GeneralEvent):
   class Pair(DynamicData):
      key: str
      value: str

   eventTypeId: str
   managedObject: ManagedObject
   data: list[Pair] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import NetOffloadCapabilities

class NetworkPolicy(DynamicData):
   class SecurityPolicy(DynamicData):
      allowPromiscuous: Optional[bool] = None
      macChanges: Optional[bool] = None
      forgedTransmits: Optional[bool] = None

   class TrafficShapingPolicy(DynamicData):
      enabled: Optional[bool] = None
      averageBandwidth: Optional[long] = None
      peakBandwidth: Optional[long] = None
      burstSize: Optional[long] = None

   class NicFailureCriteria(DynamicData):
      checkSpeed: Optional[str] = None
      speed: Optional[int] = None
      checkDuplex: Optional[bool] = None
      fullDuplex: Optional[bool] = None
      checkErrorPercent: Optional[bool] = None
      percentage: Optional[int] = None
      checkBeacon: Optional[bool] = None

   class NicOrderPolicy(DynamicData):
      activeNic: list[str] = []
      standbyNic: list[str] = []

   class NicTeamingPolicy(DynamicData):
      policy: Optional[str] = None
      reversePolicy: Optional[bool] = None
      notifySwitches: Optional[bool] = None
      rollingOrder: Optional[bool] = None
      failureCriteria: Optional[NicFailureCriteria] = None
      nicOrder: Optional[NicOrderPolicy] = None

   security: Optional[SecurityPolicy] = None
   nicTeaming: Optional[NicTeamingPolicy] = None
   offloadPolicy: Optional[NetOffloadCapabilities] = None
   shapingPolicy: Optional[TrafficShapingPolicy] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.fault import VimFault

class HostHasComponentFailure(VimFault):
   class HostComponentType(Enum):
      Datastore: ClassVar['HostComponentType'] = 'Datastore'

   hostName: str
   componentType: str
   componentName: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import HostSystem

from pyVmomi.vim.vsan import VsanNetworkConfigBaseIssue

class VsanNetworkConfigPnicSpeedInconsistencyIssue(VsanNetworkConfigBaseIssue):
   host: HostSystem
   vswitchName: Optional[str] = None
   vds: Optional[DistributedVirtualSwitch] = None
   speedsMb: list[long] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn

from pyVmomi.vim import ExtensibleManagedObject

from pyVmomi.vim.host import ServiceInfo

class ServiceSystem(ExtensibleManagedObject):
   @property
   def serviceInfo(self) -> ServiceInfo: ...

   def UpdatePolicy(self, id: str, policy: str) -> NoReturn: ...
   def Start(self, id: str) -> NoReturn: ...
   def Stop(self, id: str) -> NoReturn: ...
   def Restart(self, id: str) -> NoReturn: ...
   def Uninstall(self, id: str) -> NoReturn: ...
   def Refresh(self) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.event import HostEvent
from pyVmomi.vim.event import HostEventArgument
from pyVmomi.vim.event import VmEventArgument

class HostWwnConflictEvent(HostEvent):
   conflictedVms: list[VmEventArgument] = []
   conflictedHosts: list[HostEventArgument] = []
   wwn: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ScsiDisk

class DiskMappingCreationSpec(DynamicData):
   class DiskMappingCreationType(Enum):
      hybrid: ClassVar['DiskMappingCreationType'] = 'hybrid'
      allFlash: ClassVar['DiskMappingCreationType'] = 'allFlash'
      vsandirect: ClassVar['DiskMappingCreationType'] = 'vsandirect'
      pmem: ClassVar['DiskMappingCreationType'] = 'pmem'
      DiskMappingCreationType_Unknown: ClassVar['DiskMappingCreationType'] = 'DiskMappingCreationType_Unknown'

   host: HostSystem
   cacheDisks: list[ScsiDisk] = []
   capacityDisks: list[ScsiDisk] = []
   creationType: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ComputeResource
from pyVmomi.vim import Datastore
from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import Folder
from pyVmomi.vim import HostSystem
from pyVmomi.vim import ResourcePool
from pyVmomi.vim import SDDCBase
from pyVmomi.vim import Task
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

from pyVmomi.vim.cluster import ActionHistory
from pyVmomi.vim.cluster import ConfigInfo
from pyVmomi.vim.cluster import ConfigSpec
from pyVmomi.vim.cluster import ConfigSpecEx
from pyVmomi.vim.cluster import DasAdmissionControlInfo
from pyVmomi.vim.cluster import DasAdvancedRuntimeInfo
from pyVmomi.vim.cluster import DasData
from pyVmomi.vim.cluster import DrsFaults
from pyVmomi.vim.cluster import DrsMigration
from pyVmomi.vim.cluster import DrsRecommendation
from pyVmomi.vim.cluster import EVCManager
from pyVmomi.vim.cluster import EnterMaintenanceResult
from pyVmomi.vim.cluster import HostRecommendation
from pyVmomi.vim.cluster import PlacementResult
from pyVmomi.vim.cluster import PlacementSpec
from pyVmomi.vim.cluster import Recommendation
from pyVmomi.vim.cluster import ResourceUsageSummary
from pyVmomi.vim.cluster import RuleInfo
from pyVmomi.vim.cluster import UsageSummary

from pyVmomi.vim.dvs import DistributedVirtualPortgroup

from pyVmomi.vim.encryption import CryptoKeyId
from pyVmomi.vim.encryption import KeyProviderId

from pyVmomi.vim.host import ConnectSpec
from pyVmomi.vim.host import DateTimeConfig
from pyVmomi.vim.host import HostAccessManager
from pyVmomi.vim.host import VirtualNic

from pyVmomi.vim.option import OptionValue

class ClusterComputeResource(ComputeResource):
   class Summary(ComputeResource.Summary):
      currentFailoverLevel: int
      admissionControlInfo: Optional[DasAdmissionControlInfo] = None
      numVmotions: int
      targetBalance: Optional[int] = None
      currentBalance: Optional[int] = None
      drsScore: Optional[int] = None
      numVmsPerDrsScoreBucket: list[int] = []
      usageSummary: Optional[UsageSummary] = None
      currentEVCModeKey: Optional[str] = None
      currentEVCGraphicsModeKey: Optional[str] = None
      dasData: Optional[DasData] = None
      clusterMaintenanceModeStatus: Optional[str] = None
      vcsHealthStatus: Optional[str] = None
      vcsSlots: list[VcsSlots] = []

   class DVSSetting(DynamicData):
      class DVPortgroupToServiceMapping(DynamicData):
         dvPortgroup: DistributedVirtualPortgroup
         service: str

      dvSwitch: DistributedVirtualSwitch
      pnicDevices: list[str] = []
      dvPortgroupSetting: list[DVPortgroupToServiceMapping] = []

   class HCIWorkflowState(Enum):
      in_progress: ClassVar['HCIWorkflowState'] = 'in_progress'
      done: ClassVar['HCIWorkflowState'] = 'done'
      invalid: ClassVar['HCIWorkflowState'] = 'invalid'

   class HostConfigurationProfile(DynamicData):
      dateTimeConfig: Optional[DateTimeConfig] = None
      lockdownMode: Optional[HostAccessManager.LockdownMode] = None

   class HCIConfigInfo(DynamicData):
      workflowState: str
      dvsSetting: list[DVSSetting] = []
      configuredHosts: list[HostSystem] = []
      hostConfigProfile: Optional[HostConfigurationProfile] = None

   class ClusterConfigResult(DynamicData):
      failedHosts: list[Folder.FailedHostResult] = []
      configuredHosts: list[HostSystem] = []

   class DvsProfile(DynamicData):
      class DVPortgroupSpecToServiceMapping(DynamicData):
         dvPortgroupSpec: Optional[DistributedVirtualPortgroup.ConfigSpec] = None
         dvPortgroup: Optional[DistributedVirtualPortgroup] = None
         service: str

      dvsName: Optional[str] = None
      dvSwitch: Optional[DistributedVirtualSwitch] = None
      pnicDevices: list[str] = []
      dvPortgroupMapping: list[DVPortgroupSpecToServiceMapping] = []

   class VCProfile(DynamicData):
      clusterSpec: Optional[ConfigSpecEx] = None
      evcModeKey: Optional[str] = None
      evcGraphicsModeKey: Optional[str] = None

   class HCIConfigSpec(DynamicData):
      dvsProf: list[DvsProfile] = []
      hostConfigProfile: Optional[HostConfigurationProfile] = None
      vSanConfigSpec: Optional[SDDCBase] = None
      vcProf: Optional[VCProfile] = None

   class HostVmkNicInfo(DynamicData):
      nicSpec: VirtualNic.Specification
      service: str

   class HostConfigurationInput(DynamicData):
      host: HostSystem
      hostVmkNics: list[HostVmkNicInfo] = []
      allowedInNonMaintenanceMode: Optional[bool] = None

   class ValidationResultBase(DynamicData):
      info: list[LocalizableMessage] = []

   class HostConfigurationValidation(ValidationResultBase):
      host: HostSystem
      isDvsSettingValid: Optional[bool] = None
      isVmknicSettingValid: Optional[bool] = None
      isNtpSettingValid: Optional[bool] = None
      isLockdownModeValid: Optional[bool] = None

   class DVSConfigurationValidation(ValidationResultBase):
      isDvsValid: bool
      isDvpgValid: bool

   class HostEvacuationInfo(DynamicData):
      host: HostSystem
      action: list[OptionValue] = []

   class MaintenanceInfo(DynamicData):
      partialMMId: Optional[str] = None
      hostEvacInfo: list[HostEvacuationInfo] = []

   class CryptoModePolicy(DynamicData):
      keyId: Optional[CryptoKeyId] = None
      providerId: Optional[KeyProviderId] = None

   class VcsHealthStatus(Enum):
      healthy: ClassVar['VcsHealthStatus'] = 'healthy'
      degraded: ClassVar['VcsHealthStatus'] = 'degraded'
      nonhealthy: ClassVar['VcsHealthStatus'] = 'nonhealthy'

   class VcsSlots(DynamicData):
      systemId: Optional[str] = None
      host: HostSystem
      datastore: list[Datastore] = []
      totalSlots: int

   @property
   def configuration(self) -> ConfigInfo: ...
   @property
   def recommendation(self) -> list[Recommendation]: ...
   @property
   def drsRecommendation(self) -> list[DrsRecommendation]: ...
   @property
   def summaryEx(self) -> Summary: ...
   @property
   def hciConfig(self) -> Optional[HCIConfigInfo]: ...
   @property
   def migrationHistory(self) -> list[DrsMigration]: ...
   @property
   def actionHistory(self) -> list[ActionHistory]: ...
   @property
   def drsFault(self) -> list[DrsFaults]: ...

   def ConfigureHCI(self, clusterSpec: HCIConfigSpec, hostInputs: list[HostConfigurationInput]) -> Task: ...
   def ExtendHCI(self, hostInputs: list[HostConfigurationInput], vSanConfigSpec: Optional[SDDCBase]) -> Task: ...
   def AbandonHciWorkflow(self) -> NoReturn: ...
   def ValidateHCIConfiguration(self, hciConfigSpec: Optional[HCIConfigSpec], hosts: list[HostSystem]) -> list[ValidationResultBase]: ...
   def Reconfigure(self, spec: ConfigSpec, modify: bool) -> Task: ...
   def ApplyRecommendation(self, key: str) -> NoReturn: ...
   def CancelRecommendation(self, key: str) -> NoReturn: ...
   def RecommendHostsForVm(self, vm: VirtualMachine, pool: Optional[ResourcePool]) -> list[HostRecommendation]: ...
   def AddHost(self, spec: ConnectSpec, asConnected: bool, resourcePool: Optional[ResourcePool], license: Optional[str]) -> Task: ...
   def MoveInto(self, host: list[HostSystem]) -> Task: ...
   def MoveHostInto(self, host: HostSystem, resourcePool: Optional[ResourcePool]) -> Task: ...
   def RefreshRecommendation(self) -> NoReturn: ...
   def EvcManager(self) -> Optional[EVCManager]: ...
   def RetrieveDasAdvancedRuntimeInfo(self) -> Optional[DasAdvancedRuntimeInfo]: ...
   def EnterMaintenanceMode(self, host: list[HostSystem], option: list[OptionValue], info: Optional[MaintenanceInfo]) -> EnterMaintenanceResult: ...
   def PlaceVm(self, placementSpec: PlacementSpec) -> PlacementResult: ...
   def FindRulesForVm(self, vm: VirtualMachine) -> list[RuleInfo]: ...
   def StampAllRulesWithUuid(self) -> Task: ...
   def GetResourceUsage(self) -> ResourceUsageSummary: ...
   def SetCryptoMode(self, cryptoMode: str, policy: Optional[CryptoModePolicy]) -> NoReturn: ...
   def GetSystemVMsRestrictedDatastores(self) -> list[Datastore]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Datacenter

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vApp import IpPool

class IpPoolManager(ManagedObject):
   class IpAllocation(DynamicData):
      ipAddress: str
      allocationId: str

   def QueryIpPools(self, dc: Datacenter) -> list[IpPool]: ...
   def CreateIpPool(self, dc: Datacenter, pool: IpPool) -> int: ...
   def UpdateIpPool(self, dc: Datacenter, pool: IpPool) -> NoReturn: ...
   def DestroyIpPool(self, dc: Datacenter, id: int, force: bool) -> NoReturn: ...
   def AllocateIpv4Address(self, dc: Datacenter, poolId: int, allocationId: str) -> str: ...
   def AllocateIpv6Address(self, dc: Datacenter, poolId: int, allocationId: str) -> str: ...
   def ReleaseIpAllocation(self, dc: Datacenter, poolId: int, allocationId: str) -> NoReturn: ...
   def QueryIPAllocations(self, dc: Datacenter, poolId: int, extensionKey: str) -> list[IpAllocation]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.event import Event

class DvsEvent(Event):
   class PortBlockState(Enum):
      unset: ClassVar['PortBlockState'] = 'unset'
      blocked: ClassVar['PortBlockState'] = 'blocked'
      unblocked: ClassVar['PortBlockState'] = 'unblocked'
      unknown: ClassVar['PortBlockState'] = 'unknown'



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class BootOptions(DynamicData):
   class NetworkBootProtocolType(Enum):
      ipv4: ClassVar['NetworkBootProtocolType'] = 'ipv4'
      ipv6: ClassVar['NetworkBootProtocolType'] = 'ipv6'

   class BootableDevice(DynamicData):
      pass

   class BootableDiskDevice(BootableDevice):
      deviceKey: int

   class BootableEthernetDevice(BootableDevice):
      deviceKey: int

   class BootableFloppyDevice(BootableDevice):
      pass

   class BootableCdromDevice(BootableDevice):
      pass

   bootDelay: Optional[long] = None
   enterBIOSSetup: Optional[bool] = None
   efiSecureBootEnabled: Optional[bool] = None
   bootRetryEnabled: Optional[bool] = None
   bootRetryDelay: Optional[long] = None
   bootOrder: list[BootableDevice] = []
   networkBootProtocol: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class DiskClaimConfiguration(DynamicData):
   diskType: str
   diskNamePrefix: Optional[str] = None
   numberOfDisks: Optional[int] = None
   diskModel: Optional[str] = None
   vendor: Optional[str] = None
   diskCapacity: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore
from pyVmomi.vim import KeyValue
from pyVmomi.vim import Task

from pyVmomi.vim.encryption import CryptoSpec

from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vslm import CloneSpec
from pyVmomi.vim.vslm import CreateSpec
from pyVmomi.vim.vslm import ID
from pyVmomi.vim.vslm import InfrastructureObjectPolicy
from pyVmomi.vim.vslm import RelocateSpec
from pyVmomi.vim.vslm import StateInfo
from pyVmomi.vim.vslm import VStorageObject
from pyVmomi.vim.vslm import VStorageObjectManagerBase
from pyVmomi.vim.vslm import VStorageObjectSnapshotInfo

class VStorageObjectManager(VStorageObjectManagerBase):
   def CreateDisk(self, spec: CreateSpec) -> Task: ...
   def RegisterDisk(self, path: str, name: Optional[str], modifyControlFlags: Optional[bool]) -> VStorageObject: ...
   def ExtendDisk(self, id: ID, datastore: Datastore, newCapacityInMB: long) -> Task: ...
   def InflateDisk(self, id: ID, datastore: Datastore) -> Task: ...
   def RenameVStorageObject(self, id: ID, datastore: Datastore, name: str) -> NoReturn: ...
   def RetrieveVStorageInfrastructureObjectPolicy(self, datastore: Datastore) -> list[InfrastructureObjectPolicy]: ...
   def DeleteVStorageObject(self, id: ID, datastore: Datastore) -> Task: ...
   def RetrieveVStorageObject(self, id: ID, datastore: Datastore, diskInfoFlags: list[str]) -> VStorageObject: ...
   def RetrieveVStorageObjectState(self, id: ID, datastore: Datastore) -> StateInfo: ...
   def ListVStorageObject(self, datastore: Datastore) -> list[ID]: ...
   def CloneVStorageObject(self, id: ID, datastore: Datastore, spec: CloneSpec) -> Task: ...
   def RelocateVStorageObject(self, id: ID, datastore: Datastore, spec: RelocateSpec) -> Task: ...
   def SetVStorageObjectControlFlags(self, id: ID, datastore: Datastore, controlFlags: list[str]) -> NoReturn: ...
   def ClearVStorageObjectControlFlags(self, id: ID, datastore: Datastore, controlFlags: list[str]) -> NoReturn: ...
   def ReconcileDatastoreInventory(self, datastore: Datastore, deepCleansing: Optional[bool]) -> Task: ...
   def ScheduleReconcileDatastoreInventory(self, datastore: Datastore, deepCleansing: Optional[bool]) -> NoReturn: ...
   def CreateSnapshot(self, id: ID, datastore: Datastore, description: str) -> Task: ...
   def DeleteSnapshot(self, id: ID, datastore: Datastore, snapshotId: ID) -> Task: ...
   def RetrieveSnapshotInfo(self, id: ID, datastore: Datastore) -> VStorageObjectSnapshotInfo: ...
   def CreateDiskFromSnapshot(self, id: ID, datastore: Datastore, snapshotId: ID, name: str, profile: list[ProfileSpec], crypto: Optional[CryptoSpec], path: Optional[str], provisioningType: Optional[str]) -> Task: ...
   def RevertVStorageObject(self, id: ID, datastore: Datastore, snapshotId: ID) -> Task: ...
   def UpdateVStorageObjectMetadata(self, id: ID, datastore: Datastore, metadata: list[KeyValue], deleteKeys: list[str]) -> Task: ...
   def RetrieveVStorageObjectMetadata(self, id: ID, datastore: Datastore, snapshotId: Optional[ID], prefix: Optional[str]) -> list[KeyValue]: ...
   def RetrieveVStorageObjectMetadataValue(self, id: ID, datastore: Datastore, snapshotId: Optional[ID], key: str) -> str: ...
   def DeleteVStorageObjectEx(self, id: ID, datastore: Datastore) -> Task: ...
   def UpdateVStorageObjectMetadataEx(self, id: ID, datastore: Datastore, metadata: list[KeyValue], deleteKeys: list[str]) -> Task: ...
   def SetVirtualDiskUuidEx(self, name: str, uuid: Optional[str]) -> Task: ...
   def QueryVirtualDiskUuidEx(self, name: str) -> str: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import ClusterComputeResource
from pyVmomi.vim import Datastore
from pyVmomi.vim import Task

from pyVmomi.vim.vsan import DatastoreSourcePrecheckResult
from pyVmomi.vim.vsan import HciMeshDatastoreSource
from pyVmomi.vim.vsan import MountPrecheckResult
from pyVmomi.vim.vsan import RemoteVcInfo
from pyVmomi.vim.vsan import VcRemoteVsanServerClusterInfo
from pyVmomi.vim.vsan import XVCDatastoreInfo
from pyVmomi.vim.vsan import XvcQueryResultSet
from pyVmomi.vim.vsan import XvcQuerySpec

class VsanRemoteDatastoreSystem(ManagedObject):
   def MountPrecheck(self, cluster: ClusterComputeResource, datastore: Datastore, serverClusterInfo: Optional[VcRemoteVsanServerClusterInfo]) -> MountPrecheckResult: ...
   def RemoteVcMountPrecheck(self, cluster: ClusterComputeResource, xvcDatastore: XVCDatastoreInfo) -> MountPrecheckResult: ...
   def QueryDatastoreSource(self, vcHosts: list[str]) -> list[HciMeshDatastoreSource]: ...
   def PrecheckDatastoreSource(self, datastoreSource: HciMeshDatastoreSource, operation: Optional[str]) -> DatastoreSourcePrecheckResult: ...
   def CreateDatastoreSource(self, datastoreSource: HciMeshDatastoreSource) -> Task: ...
   def UpdateDatastoreSource(self, datastoreSource: HciMeshDatastoreSource) -> Task: ...
   def DestroyDatastoreSource(self, datastoreSource: HciMeshDatastoreSource) -> Task: ...
   def QueryHciMeshDatastores(self, querySpecs: list[XvcQuerySpec], extraVcInfos: list[RemoteVcInfo]) -> list[XvcQueryResultSet]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.host import VsanDiskEncryptionHealth
from pyVmomi.vim.host import VsanKmsHealth

from pyVmomi.vim.vsan.host import EncryptionInfo

class VsanEncryptionHealthSummary(DynamicData):
   hostname: Optional[str] = None
   encryptionInfo: Optional[EncryptionInfo] = None
   overallKmsHealth: str
   kmsHealth: list[VsanKmsHealth] = []
   encryptionIssues: list[str] = []
   diskResults: list[VsanDiskEncryptionHealth] = []
   error: Optional[MethodFault] = None
   aesniEnabled: Optional[bool] = None
   inconsistentlyEncryptedObjectCount: Optional[long] = None
   hostEncryptionDekId: Optional[str] = None
   kekVerifierHealth: Optional[bool] = None
   dekVerifierHealth: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Folder

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import TargetInfo

class SubnetInfo(TargetInfo):
   class FolderInfo(DynamicData):
      name: str
      folder: Folder

   id: str
   subnetFolderInfo: FolderInfo
   vpcFolderInfo: FolderInfo
   projectFolderInfo: Optional[FolderInfo] = None
   rootFolderInfo: FolderInfo



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.vm.device import VirtualDeviceOption

class VirtualParallelPortOption(VirtualDeviceOption):
   class FileBackingOption(VirtualDeviceOption.FileBackingOption):
      pass

   class DeviceBackingOption(VirtualDeviceOption.DeviceBackingOption):
      pass



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import ElementDescription
from pyVmomi.vim import EnumDescription

from pyVmomi.vmodl import DynamicData

class EventDescription(DynamicData):
   class EventCategory(Enum):
      info: ClassVar['EventCategory'] = 'info'
      warning: ClassVar['EventCategory'] = 'warning'
      error: ClassVar['EventCategory'] = 'error'
      user: ClassVar['EventCategory'] = 'user'

   class EventArgDesc(DynamicData):
      name: str
      type: str
      description: Optional[ElementDescription] = None

   class EventDetail(DynamicData):
      key: type
      description: Optional[str] = None
      category: str
      formatOnDatacenter: str
      formatOnComputeResource: str
      formatOnHost: str
      formatOnVm: str
      fullFormat: str
      longDescription: Optional[str] = None

   category: list[ElementDescription] = []
   eventInfo: list[EventDetail] = []
   enumeratedTypes: list[EnumDescription] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ScsiDisk

class UnresolvedVmfsExtent(DynamicData):
   class UnresolvedReason(Enum):
      diskIdMismatch: ClassVar['UnresolvedReason'] = 'diskIdMismatch'
      uuidConflict: ClassVar['UnresolvedReason'] = 'uuidConflict'

   device: ScsiDisk.Partition
   devicePath: str
   vmfsUuid: str
   isHeadExtent: bool
   ordinal: int
   startBlock: int
   endBlock: int
   reason: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vslm import BaseConfigInfo
from pyVmomi.vim.vslm import ID

class VStorageObject(DynamicData):
   class ConsumptionType(Enum):
      disk: ClassVar['ConsumptionType'] = 'disk'

   class ConfigInfo(BaseConfigInfo):
      descriptorVersion: Optional[int] = None
      capacityInMB: long
      consumptionType: list[str] = []
      consumerId: list[ID] = []
      virtualDiskFormat: Optional[str] = None

   config: ConfigInfo



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class SgxInfo(DynamicData):
   class FlcModes(Enum):
      locked: ClassVar['FlcModes'] = 'locked'
      unlocked: ClassVar['FlcModes'] = 'unlocked'

   epcSize: long
   flcMode: Optional[str] = None
   lePubKeyHash: Optional[str] = None
   requireAttestation: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.vm.device import VirtualController
from pyVmomi.vim.vm.device import VirtualDevice

class VirtualUSBController(VirtualController):
   class PciBusSlotInfo(VirtualDevice.PciBusSlotInfo):
      ehciPciSlotNumber: Optional[int] = None

   autoConnectDevices: Optional[bool] = None
   ehciEnabled: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class FaultToleranceConfigInfo(DynamicData):
   role: int
   instanceUuids: list[str] = []
   configPaths: list[str] = []
   orphaned: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import CustomFieldsManager

class ExtensibleManagedObject(ManagedObject):
   @property
   def value(self) -> list[CustomFieldsManager.Value]: ...
   @property
   def availableField(self) -> list[CustomFieldsManager.FieldDef]: ...

   def SetCustomValue(self, key: str, value: str) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import Capability
from pyVmomi.vim.vm import DatastoreOption
from pyVmomi.vim.vm import GuestOsDescriptor
from pyVmomi.vim.vm import PropertyRelation
from pyVmomi.vim.vm import VirtualHardwareOption

from pyVmomi.vim.vm.device import VirtualDevice

class ConfigOption(DynamicData):
   version: str
   description: str
   guestOSDescriptor: list[GuestOsDescriptor] = []
   guestOSDefaultIndex: int
   hardwareOptions: VirtualHardwareOption
   capabilities: Capability
   datastore: DatastoreOption
   defaultDevice: list[VirtualDevice] = []
   supportedMonitorType: list[str] = []
   supportedOvfEnvironmentTransport: list[str] = []
   supportedOvfInstallTransport: list[str] = []
   propertyRelations: list[PropertyRelation] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import ScsiDisk
from pyVmomi.vim.host import VsanDiskRebalanceResult

class VsanPhysicalDiskHealth(DynamicData):
   name: str
   uuid: str
   inCmmds: bool
   inVsi: bool
   dedupScope: Optional[long] = None
   formatVersion: Optional[int] = None
   isAllFlash: Optional[int] = None
   congestionValue: Optional[int] = None
   congestionArea: Optional[str] = None
   congestionHealth: Optional[str] = None
   metadataHealth: Optional[str] = None
   operationalHealthDescription: Optional[str] = None
   operationalHealth: Optional[str] = None
   dedupUsageHealth: Optional[str] = None
   capacityHealth: Optional[str] = None
   summaryHealth: str
   capacity: Optional[long] = None
   usedCapacity: Optional[long] = None
   reservedCapacity: Optional[long] = None
   totalBytes: Optional[long] = None
   freeBytes: Optional[long] = None
   hashedBytes: Optional[long] = None
   dedupedBytes: Optional[long] = None
   scsiDisk: Optional[ScsiDisk] = None
   usedComponents: Optional[long] = None
   maxComponents: Optional[long] = None
   compLimitHealth: Optional[str] = None
   encryptionEnabled: Optional[bool] = None
   kmsProviderId: Optional[str] = None
   kekId: Optional[str] = None
   dekGenerationId: Optional[long] = None
   encryptedUnlocked: Optional[bool] = None
   rebalanceResult: Optional[VsanDiskRebalanceResult] = None
   dekId: Optional[str] = None
   kekVerifierHealth: Optional[bool] = None
   dekVerifierHealth: Optional[bool] = None
   logicalCapacity: Optional[long] = None
   logicalCapacityUsed: Optional[long] = None
   logicalCapacityHealth: Optional[str] = None
   vsanDiskGroupUuid: Optional[str] = None
   dgLayoutIssue: Optional[bool] = None
   usedMetadataComponents: Optional[long] = None
   maxMetadataComponents: Optional[long] = None
   pendingClusterDekId: Optional[str] = None
   dmekVerifierHealth: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import double
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ClusterComputeResource

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import MethodFault

class PlacementRankResult(DynamicData):
   key: str
   candidate: ClusterComputeResource
   reservedSpaceMB: long
   usedSpaceMB: long
   totalSpaceMB: long
   utilization: double
   faults: list[MethodFault] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskConfigurationResult
from pyVmomi.vim.host import VffsVolume

class VFlashResourceConfigurationResult(DynamicData):
   devicePath: list[str] = []
   vffs: Optional[VffsVolume] = None
   diskConfigurationResult: list[DiskConfigurationResult] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import DistributedVirtualSwitch
from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanVdsPgMigrationSpec

class VsanVdsMigrationPlan(DynamicData):
   vdsSpec: DistributedVirtualSwitch.CreateSpec
   pgs: list[VsanVdsPgMigrationSpec] = []
   inaccessibleVms: list[VirtualMachine] = []
   infraVms: list[VirtualMachine] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanSpaceEfficiencyMetadataSize

class DataEfficiencyCapacityState(DynamicData):
   logicalCapacity: Optional[long] = None
   logicalCapacityUsed: Optional[long] = None
   physicalCapacity: Optional[long] = None
   physicalCapacityUsed: Optional[long] = None
   dedupMetadataSize: Optional[long] = None
   spaceEfficiencyMetadataSize: Optional[VsanSpaceEfficiencyMetadataSize] = None
   esaDedupSpaceSaving: Optional[long] = None
   esaCompressionSpaceSaving: Optional[long] = None
   totalSpaceUsedWithoutOverhead: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class VmReadiness(DynamicData):
   class ReadyCondition(Enum):
      none: ClassVar['ReadyCondition'] = 'none'
      poweredOn: ClassVar['ReadyCondition'] = 'poweredOn'
      guestHbStatusGreen: ClassVar['ReadyCondition'] = 'guestHbStatusGreen'
      appHbStatusGreen: ClassVar['ReadyCondition'] = 'appHbStatusGreen'
      useClusterDefault: ClassVar['ReadyCondition'] = 'useClusterDefault'

   readyCondition: Optional[str] = None
   postReadyDelay: Optional[int] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vim.vm import ProfileRawData
from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vm.replication import ReplicationSpec

class DefinedProfileSpec(ProfileSpec):
   profileId: str
   replicationSpec: Optional[ReplicationSpec] = None
   profileData: Optional[ProfileRawData] = None
   profileParams: list[KeyValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import byte
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskDimensions

class DiskPartitionInfo(DynamicData):
   class PartitionFormat(Enum):
      gpt: ClassVar['PartitionFormat'] = 'gpt'
      mbr: ClassVar['PartitionFormat'] = 'mbr'
      unknown: ClassVar['PartitionFormat'] = 'unknown'

   class Type(Enum):
      none: ClassVar['Type'] = 'none'
      vmfs: ClassVar['Type'] = 'vmfs'
      linuxNative: ClassVar['Type'] = 'linuxNative'
      linuxSwap: ClassVar['Type'] = 'linuxSwap'
      extended: ClassVar['Type'] = 'extended'
      ntfs: ClassVar['Type'] = 'ntfs'
      vmkDiagnostic: ClassVar['Type'] = 'vmkDiagnostic'
      vffs: ClassVar['Type'] = 'vffs'

   class Partition(DynamicData):
      partition: int
      startSector: long
      endSector: long
      type: str
      guid: Optional[str] = None
      logical: bool
      attributes: byte
      partitionAlignment: Optional[long] = None

   class BlockRange(DynamicData):
      partition: Optional[int] = None
      type: str
      start: DiskDimensions.Lba
      end: DiskDimensions.Lba

   class Specification(DynamicData):
      partitionFormat: Optional[str] = None
      chs: Optional[DiskDimensions.Chs] = None
      totalSectors: Optional[long] = None
      partition: list[Partition] = []
      sectorSize: Optional[int] = None

   class Layout(DynamicData):
      total: Optional[DiskDimensions.Lba] = None
      partition: list[BlockRange] = []

   deviceName: str
   spec: Specification
   layout: Layout



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class SharesInfo(DynamicData):
   class Level(Enum):
      low: ClassVar['Level'] = 'low'
      normal: ClassVar['Level'] = 'normal'
      high: ClassVar['Level'] = 'high'
      custom: ClassVar['Level'] = 'custom'

   shares: int
   level: Level



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import StorageOperationalStatus
from pyVmomi.vim.cluster import StoragePolicyStatus

class StorageComplianceResult(DynamicData):
   class StorageComplianceStatus(Enum):
      compliant: ClassVar['StorageComplianceStatus'] = 'compliant'
      nonCompliant: ClassVar['StorageComplianceStatus'] = 'nonCompliant'
      unknown: ClassVar['StorageComplianceStatus'] = 'unknown'
      notApplicable: ClassVar['StorageComplianceStatus'] = 'notApplicable'

   checkTime: Optional[datetime] = None
   profile: Optional[str] = None
   objectUUID: Optional[str] = None
   complianceStatus: str
   mismatch: bool
   violatedPolicies: list[StoragePolicyStatus] = []
   operationalStatus: Optional[StorageOperationalStatus] = None
   objPolicyGenerationId: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Folder

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import GatewaySpec
from pyVmomi.vim.host import HostAccessManager

class ConnectSpec(DynamicData):
   hostName: Optional[str] = None
   port: Optional[int] = None
   sslThumbprint: Optional[str] = None
   sslCertificate: Optional[str] = None
   userName: Optional[str] = None
   password: Optional[str] = None
   vmFolder: Optional[Folder] = None
   force: bool
   vimAccountName: Optional[str] = None
   vimAccountPassword: Optional[str] = None
   managementIp: Optional[str] = None
   lockdownMode: Optional[HostAccessManager.LockdownMode] = None
   hostGateway: Optional[GatewaySpec] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import HostBusAdapter
from pyVmomi.vim.host import ScsiLun
from pyVmomi.vim.host import TargetTransport

class MultipathInfo(DynamicData):
   class PathState(Enum):
      standby: ClassVar['PathState'] = 'standby'
      active: ClassVar['PathState'] = 'active'
      disabled: ClassVar['PathState'] = 'disabled'
      dead: ClassVar['PathState'] = 'dead'
      unknown: ClassVar['PathState'] = 'unknown'

   class LogicalUnitPolicy(DynamicData):
      policy: str

   class HppLogicalUnitPolicy(LogicalUnitPolicy):
      bytes: Optional[long] = None
      iops: Optional[long] = None
      path: Optional[str] = None
      latencyEvalTime: Optional[long] = None
      samplingIosPerPath: Optional[long] = None

   class LogicalUnitStorageArrayTypePolicy(DynamicData):
      policy: str

   class FixedLogicalUnitPolicy(LogicalUnitPolicy):
      prefer: str

   class LogicalUnit(DynamicData):
      key: str
      id: str
      lun: ScsiLun
      path: list[Path] = []
      policy: LogicalUnitPolicy
      storageArrayTypePolicy: Optional[LogicalUnitStorageArrayTypePolicy] = None

   class Path(DynamicData):
      key: str
      name: str
      pathState: str
      state: Optional[str] = None
      isWorkingPath: Optional[bool] = None
      adapter: HostBusAdapter
      lun: LogicalUnit
      transport: Optional[TargetTransport] = None

   lun: list[LogicalUnit] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import KeyAnyValue
from pyVmomi.vmodl import MethodFault

from pyVmomi.vim.event import Event

class EventEx(Event):
   eventTypeId: str
   severity: Optional[str] = None
   message: Optional[str] = None
   arguments: list[KeyAnyValue] = []
   objectId: Optional[str] = None
   objectType: Optional[type] = None
   objectName: Optional[str] = None
   fault: Optional[MethodFault] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import DasAdmissionControlPolicy

class FailoverResourcesAdmissionControlPolicy(DasAdmissionControlPolicy):
   cpuFailoverResourcesPercent: int
   memoryFailoverResourcesPercent: int
   failoverLevel: Optional[int] = None
   autoComputePercentages: Optional[bool] = None
   pMemFailoverResourcesPercent: Optional[int] = None
   autoComputePMemFailoverResourcesPercent: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vsan import VsanHclDriverInfo

class VsanHclCommonDeviceInfo(DynamicData):
   deviceName: str
   displayName: Optional[str] = None
   driverName: Optional[str] = None
   driverVersion: Optional[str] = None
   vendorId: Optional[long] = None
   deviceId: Optional[long] = None
   subVendorId: Optional[long] = None
   subDeviceId: Optional[long] = None
   extraInfo: list[KeyValue] = []
   deviceOnHcl: Optional[bool] = None
   releaseSupported: Optional[bool] = None
   releasesOnHcl: list[str] = []
   driverVersionsOnHcl: list[str] = []
   driverVersionSupported: Optional[bool] = None
   fwVersionSupported: Optional[bool] = None
   fwVersionOnHcl: list[str] = []
   fwVersion: Optional[str] = None
   driversOnHcl: list[VsanHclDriverInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import DasConfigInfo
from pyVmomi.vim.cluster import DasVmConfigInfo
from pyVmomi.vim.cluster import DrsConfigInfo
from pyVmomi.vim.cluster import DrsVmConfigInfo
from pyVmomi.vim.cluster import RuleInfo

class ConfigInfo(DynamicData):
   dasConfig: DasConfigInfo
   dasVmConfig: list[DasVmConfigInfo] = []
   drsConfig: DrsConfigInfo
   drsVmConfig: list[DrsVmConfigInfo] = []
   rule: list[RuleInfo] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import StorageComplianceResult

class VsanObjectInformation(DynamicData):
   directoryName: Optional[str] = None
   vsanObjectUuid: Optional[str] = None
   vsanHealth: Optional[str] = None
   policyAttributes: list[KeyValue] = []
   spbmProfileUuid: Optional[str] = None
   spbmProfileGenerationId: Optional[str] = None
   spbmComplianceResult: Optional[StorageComplianceResult] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .AlarmFilter import AlarmFilter as AlarmFilter
from .AlarmResult import AlarmResult as AlarmResult
from .Provider import Provider as Provider
from .ProviderInfo import ProviderInfo as ProviderInfo
from .ProviderSpec import ProviderSpec as ProviderSpec
from .VASAProviderUpgradeSpec import VASAProviderUpgradeSpec as VASAProviderUpgradeSpec
from .VasaProvider import VasaProvider as VasaProvider
from .VasaProviderInfo import VasaProviderInfo as VasaProviderInfo
from .VasaProviderSpec import VasaProviderSpec as VasaProviderSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim.vsan.host import ConfigInfo

class PortConfigEx(ConfigInfo.NetworkInfo.PortConfig):
   class TrafficType(Enum):
      vsan: ClassVar['TrafficType'] = 'vsan'
      witness: ClassVar['TrafficType'] = 'witness'
      TrafficType_Unknown: ClassVar['TrafficType'] = 'TrafficType_Unknown'

   class TrafficType90(Enum):
      vsanExternal: ClassVar['TrafficType90'] = 'vsanExternal'

   trafficTypes: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vmodl import DynamicData

class ServerObjectRef(DynamicData):
   class VvolType(Enum):
      Config: ClassVar['VvolType'] = 'Config'
      Data: ClassVar['VvolType'] = 'Data'
      Swap: ClassVar['VvolType'] = 'Swap'

   class ObjectType(Enum):
      virtualMachine: ClassVar['ObjectType'] = 'virtualMachine'
      virtualMachineAndDisks: ClassVar['ObjectType'] = 'virtualMachineAndDisks'
      virtualDiskId: ClassVar['ObjectType'] = 'virtualDiskId'
      virtualDiskUUID: ClassVar['ObjectType'] = 'virtualDiskUUID'
      datastore: ClassVar['ObjectType'] = 'datastore'
      vsanObjectId: ClassVar['ObjectType'] = 'vsanObjectId'
      fileShareId: ClassVar['ObjectType'] = 'fileShareId'
      host: ClassVar['ObjectType'] = 'host'
      cluster: ClassVar['ObjectType'] = 'cluster'
      unknown: ClassVar['ObjectType'] = 'unknown'

   objectType: str
   key: str
   serverUuid: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class SSDEnduranceThresholdSpec(DynamicData):
   clustername: str
   clusternameop: Optional[str] = None
   hostname: Optional[str] = None
   hostnameop: Optional[str] = None
   diskname: Optional[str] = None
   disknameop: Optional[str] = None
   diskvendorname: Optional[str] = None
   diskvendorop: Optional[str] = None
   ssdEndurancePtg: float
   severity: str



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum

from pyVmomi.vim import VirtualMachine

from pyVmomi.vmodl import DynamicData

class PlacementAffinityRule(DynamicData):
   class RuleType(Enum):
      affinity: ClassVar['RuleType'] = 'affinity'
      antiAffinity: ClassVar['RuleType'] = 'antiAffinity'
      softAffinity: ClassVar['RuleType'] = 'softAffinity'
      softAntiAffinity: ClassVar['RuleType'] = 'softAntiAffinity'

   class RuleScope(Enum):
      cluster: ClassVar['RuleScope'] = 'cluster'
      host: ClassVar['RuleScope'] = 'host'
      storagePod: ClassVar['RuleScope'] = 'storagePod'
      datastore: ClassVar['RuleScope'] = 'datastore'

   ruleType: str
   ruleScope: str
   vms: list[VirtualMachine] = []
   keys: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .DistributedVirtualPort import DistributedVirtualPort as DistributedVirtualPort
from .DistributedVirtualPortgroup import DistributedVirtualPortgroup as DistributedVirtualPortgroup
from .DistributedVirtualPortgroupInfo import DistributedVirtualPortgroupInfo as DistributedVirtualPortgroupInfo
from .DistributedVirtualPortgroupSelection import DistributedVirtualPortgroupSelection as DistributedVirtualPortgroupSelection
from .DistributedVirtualSwitchInfo import DistributedVirtualSwitchInfo as DistributedVirtualSwitchInfo
from .DistributedVirtualSwitchManager import DistributedVirtualSwitchManager as DistributedVirtualSwitchManager
from .DistributedVirtualSwitchSelection import DistributedVirtualSwitchSelection as DistributedVirtualSwitchSelection
from .EntityBackup import EntityBackup as EntityBackup
from .HostMember import HostMember as HostMember
from .HostProductSpec import HostProductSpec as HostProductSpec
from .KeyedOpaqueBlob import KeyedOpaqueBlob as KeyedOpaqueBlob
from .NetworkOffloadSpec import NetworkOffloadSpec as NetworkOffloadSpec
from .NetworkResourcePool import NetworkResourcePool as NetworkResourcePool
from .PortConnectee import PortConnectee as PortConnectee
from .PortConnection import PortConnection as PortConnection
from .PortCriteria import PortCriteria as PortCriteria
from .PortStatistics import PortStatistics as PortStatistics
from .ProductSpec import ProductSpec as ProductSpec
from .TrafficRule import TrafficRule as TrafficRule
from .TrafficRuleset import TrafficRuleset as TrafficRuleset
from .VmVnicNetworkResourcePool import VmVnicNetworkResourcePool as VmVnicNetworkResourcePool
from .VmwareDistributedVirtualSwitch import VmwareDistributedVirtualSwitch as VmwareDistributedVirtualSwitch



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import Datacenter
from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.fault import MigrationFault

class DatacenterMismatch(MigrationFault):
   class Argument(DynamicData):
      entity: ManagedEntity
      inputDatacenter: Optional[Datacenter] = None

   invalidArgument: list[Argument] = []
   expectedDatacenter: Datacenter



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim import Datastore

from pyVmomi.vim.cluster import Action

class HbrDiskMigrationAction(Action):
   collectionId: str
   collectionName: str
   diskIds: list[str] = []
   source: Datastore
   destination: Datastore
   sizeTransferred: long
   spaceUtilSrcBefore: Optional[float] = None
   spaceUtilDstBefore: Optional[float] = None
   spaceUtilSrcAfter: Optional[float] = None
   spaceUtilDstAfter: Optional[float] = None
   ioLatencySrcBefore: Optional[float] = None
   ioLatencyDstBefore: Optional[float] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

class UserSession(DynamicData):
   key: str
   userName: str
   fullName: str
   loginTime: datetime
   lastActiveTime: datetime
   locale: str
   messageLocale: str
   extensionSession: bool
   ipAddress: str
   userAgent: str
   callCount: long



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import ClassVar
from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject
from pyVmomi.VmomiSupport import long

from pyVmomi.vim import ElementDescription
from pyVmomi.vim import HistoricalInterval
from pyVmomi.vim import PerformanceDescription

from pyVmomi.vmodl import DynamicData

class PerformanceManager(ManagedObject):
   class Format(Enum):
      normal: ClassVar['Format'] = 'normal'
      csv: ClassVar['Format'] = 'csv'

   class ProviderSummary(DynamicData):
      entity: ManagedObject
      currentSupported: bool
      summarySupported: bool
      refreshRate: Optional[int] = None

   class CounterInfo(DynamicData):
      class RollupType(Enum):
         average: ClassVar['RollupType'] = 'average'
         maximum: ClassVar['RollupType'] = 'maximum'
         minimum: ClassVar['RollupType'] = 'minimum'
         latest: ClassVar['RollupType'] = 'latest'
         summation: ClassVar['RollupType'] = 'summation'
         none: ClassVar['RollupType'] = 'none'

      class StatsType(Enum):
         absolute: ClassVar['StatsType'] = 'absolute'
         delta: ClassVar['StatsType'] = 'delta'
         rate: ClassVar['StatsType'] = 'rate'

      class Unit(Enum):
         percent: ClassVar['Unit'] = 'percent'
         kiloBytes: ClassVar['Unit'] = 'kiloBytes'
         megaBytes: ClassVar['Unit'] = 'megaBytes'
         gigaBytes: ClassVar['Unit'] = 'gigaBytes'
         megaHertz: ClassVar['Unit'] = 'megaHertz'
         number: ClassVar['Unit'] = 'number'
         microsecond: ClassVar['Unit'] = 'microsecond'
         millisecond: ClassVar['Unit'] = 'millisecond'
         second: ClassVar['Unit'] = 'second'
         kiloBytesPerSecond: ClassVar['Unit'] = 'kiloBytesPerSecond'
         megaBytesPerSecond: ClassVar['Unit'] = 'megaBytesPerSecond'
         watt: ClassVar['Unit'] = 'watt'
         joule: ClassVar['Unit'] = 'joule'
         teraBytes: ClassVar['Unit'] = 'teraBytes'
         celsius: ClassVar['Unit'] = 'celsius'
         nanosecond: ClassVar['Unit'] = 'nanosecond'

      key: int
      nameInfo: ElementDescription
      groupInfo: ElementDescription
      unitInfo: ElementDescription
      rollupType: RollupType
      statsType: StatsType
      level: Optional[int] = None
      perDeviceLevel: Optional[int] = None
      associatedCounterId: list[int] = []

   class MetricId(DynamicData):
      counterId: int
      instance: str

   class QuerySpec(DynamicData):
      entity: ManagedObject
      startTime: Optional[datetime] = None
      endTime: Optional[datetime] = None
      maxSample: Optional[int] = None
      metricId: list[MetricId] = []
      intervalId: Optional[int] = None
      format: Optional[str] = None

   class SampleInfo(DynamicData):
      timestamp: datetime
      interval: int

   class MetricSeries(DynamicData):
      id: MetricId

   class IntSeries(MetricSeries):
      value: list[long] = []

   class MetricSeriesCSV(MetricSeries):
      value: Optional[str] = None

   class EntityMetricBase(DynamicData):
      entity: ManagedObject

   class EntityMetric(EntityMetricBase):
      sampleInfo: list[SampleInfo] = []
      value: list[MetricSeries] = []

   class EntityMetricCSV(EntityMetricBase):
      sampleInfoCSV: str
      value: list[MetricSeriesCSV] = []

   class CompositeEntityMetric(DynamicData):
      entity: Optional[EntityMetricBase] = None
      childEntity: list[EntityMetricBase] = []

   class CounterLevelMapping(DynamicData):
      counterId: int
      aggregateLevel: Optional[int] = None
      perDeviceLevel: Optional[int] = None

   @property
   def description(self) -> PerformanceDescription: ...
   @property
   def historicalInterval(self) -> list[HistoricalInterval]: ...
   @property
   def perfCounter(self) -> list[CounterInfo]: ...

   def QueryProviderSummary(self, entity: ManagedObject) -> ProviderSummary: ...
   def QueryAvailableMetric(self, entity: ManagedObject, beginTime: Optional[datetime], endTime: Optional[datetime], intervalId: Optional[int]) -> list[MetricId]: ...
   def QueryCounter(self, counterId: list[int]) -> list[CounterInfo]: ...
   def QueryCounterByLevel(self, level: int) -> list[CounterInfo]: ...
   def QueryStats(self, querySpec: list[QuerySpec]) -> list[EntityMetricBase]: ...
   def QueryCompositeStats(self, querySpec: QuerySpec) -> CompositeEntityMetric: ...
   def CreateHistoricalInterval(self, intervalId: HistoricalInterval) -> NoReturn: ...
   def RemoveHistoricalInterval(self, samplePeriod: int) -> NoReturn: ...
   def UpdateHistoricalInterval(self, interval: HistoricalInterval) -> NoReturn: ...
   def UpdateCounterLevelMapping(self, counterLevelMap: list[CounterLevelMapping]) -> NoReturn: ...
   def ResetCounterLevelMapping(self, counters: list[int]) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import EVCMode
from pyVmomi.vim import FeatureEVCMode

from pyVmomi.vmodl import DynamicData

class Capability(DynamicData):
   provisioningSupported: bool
   multiHostSupported: bool
   userShellAccessSupported: bool
   supportedEVCMode: list[EVCMode] = []
   supportedEVCGraphicsMode: list[FeatureEVCMode] = []
   networkBackupAndRestoreSupported: Optional[bool] = None
   ftDrsWithoutEvcSupported: Optional[bool] = None
   hciWorkflowSupported: Optional[bool] = None
   computePolicyVersion: Optional[int] = None
   clusterPlacementSupported: Optional[bool] = None
   lifecycleManagementSupported: Optional[bool] = None
   hostSeedingSupported: Optional[bool] = None
   scalableSharesSupported: Optional[bool] = None
   hadcsSupported: Optional[bool] = None
   configMgmtSupported: Optional[bool] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from datetime import datetime

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vim.event import SessionEvent

class UserLogoutSessionEvent(SessionEvent):
   ipAddress: Optional[str] = None
   userAgent: Optional[str] = None
   callCount: Optional[long] = None
   sessionId: Optional[str] = None
   loginTime: Optional[datetime] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import byte

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm.customization import AdapterMapping
from pyVmomi.vim.vm.customization import GlobalIPSettings
from pyVmomi.vim.vm.customization import IdentitySettings
from pyVmomi.vim.vm.customization import Options

class Specification(DynamicData):
   options: Optional[Options] = None
   identity: IdentitySettings
   globalIPSettings: GlobalIPSettings
   nicSettingMap: list[AdapterMapping] = []
   encryptionKey: list[byte] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.vm import ProfileSpec

from pyVmomi.vim.vsan import FileShareNetPermission
from pyVmomi.vim.vsan import FileShareSmbOptions

class FileShareConfig(DynamicData):
   name: Optional[str] = None
   domainName: Optional[str] = None
   quota: Optional[str] = None
   softQuota: Optional[str] = None
   labels: list[KeyValue] = []
   storagePolicy: Optional[ProfileSpec] = None
   permission: list[FileShareNetPermission] = []
   protocols: list[str] = []
   smbOptions: Optional[FileShareSmbOptions] = None
   nfsSecType: Optional[str] = None
   affinityLocation: Optional[str] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Task
from pyVmomi.vim import TaskDescription
from pyVmomi.vim import TaskFilterSpec
from pyVmomi.vim import TaskHistoryCollector
from pyVmomi.vim import TaskInfo
from pyVmomi.vim import TaskInfoFilterSpec

from pyVmomi.vmodl import DynamicData

class TaskManager(ManagedObject):
   class TaskViewSpec(DynamicData):
      pass

   class ViewByStartId(TaskViewSpec):
      count: int
      startId: str

   @property
   def recentTask(self) -> list[Task]: ...
   @property
   def description(self) -> TaskDescription: ...
   @property
   def maxCollector(self) -> int: ...

   def CreateCollector(self, filter: TaskFilterSpec) -> TaskHistoryCollector: ...
   def CreateCollectorWithInfoFilter(self, filter: TaskFilterSpec, infoFilter: Optional[TaskInfoFilterSpec]) -> TaskHistoryCollector: ...
   def CreateTask(self, obj: ManagedObject, taskTypeId: str, initiatedBy: Optional[str], cancelable: bool, parentTaskKey: Optional[str], activationId: Optional[str]) -> TaskInfo: ...
   def ReadNextTasksByViewSpec(self, viewSpec: TaskViewSpec, filterSpec: TaskFilterSpec, infoFilterSpec: Optional[TaskInfoFilterSpec]) -> list[TaskInfo]: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import KeyValue

from pyVmomi.vmodl import DynamicData
from pyVmomi.vmodl import LocalizableMessage

class VsanDataDrivenAPIAction(DynamicData):
   actionId: str
   actionLabel: LocalizableMessage
   actionDescription: LocalizableMessage
   enabled: bool
   parameters: list[KeyValue] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim.cluster import VsanIscsiTargetCommonInfo
from pyVmomi.vim.cluster import VsanObjectInformation

class VsanIscsiTarget(VsanIscsiTargetCommonInfo):
   lunCount: Optional[int] = None
   objectInformation: Optional[VsanObjectInformation] = None
   ioOwnerHost: Optional[str] = None
   initiators: list[str] = []
   initiatorGroups: list[str] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import DiskDimensions
from pyVmomi.vim.host import MountInfo

class VsanScsiDisk(DynamicData):
   capacity: DiskDimensions.Lba
   usedCapacity: Optional[long] = None
   devicePath: str
   ssd: Optional[bool] = None
   localDisk: Optional[bool] = None
   scsiDiskType: Optional[str] = None
   uuid: str
   operationalState: list[str] = []
   canonicalName: Optional[str] = None
   displayName: Optional[str] = None
   lunType: str
   vendor: Optional[str] = None
   model: Optional[str] = None
   mountInfo: Optional[MountInfo] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .Action import Action as Action
from .ActionHistory import ActionHistory as ActionHistory
from .AffinityRuleSpec import AffinityRuleSpec as AffinityRuleSpec
from .AntiAffinityRuleSpec import AntiAffinityRuleSpec as AntiAffinityRuleSpec
from .AttemptedVmInfo import AttemptedVmInfo as AttemptedVmInfo
from .ClusterInitialPlacementAction import ClusterInitialPlacementAction as ClusterInitialPlacementAction
from .ClusterPowerContext import ClusterPowerContext as ClusterPowerContext
from .ClusterPowerStatus import ClusterPowerStatus as ClusterPowerStatus
from .ConfigInfo import ConfigInfo as ConfigInfo
from .ConfigInfoEx import ConfigInfoEx as ConfigInfoEx
from .ConfigSpec import ConfigSpec as ConfigSpec
from .ConfigSpecEx import ConfigSpecEx as ConfigSpecEx
from .CryptoConfigInfo import CryptoConfigInfo as CryptoConfigInfo
from .DasAamHostInfo import DasAamHostInfo as DasAamHostInfo
from .DasAamNodeState import DasAamNodeState as DasAamNodeState
from .DasAdmissionControlInfo import DasAdmissionControlInfo as DasAdmissionControlInfo
from .DasAdmissionControlPolicy import DasAdmissionControlPolicy as DasAdmissionControlPolicy
from .DasAdvancedRuntimeInfo import DasAdvancedRuntimeInfo as DasAdvancedRuntimeInfo
from .DasConfigInfo import DasConfigInfo as DasConfigInfo
from .DasData import DasData as DasData
from .DasDataSummary import DasDataSummary as DasDataSummary
from .DasFailoverLevelAdvancedRuntimeInfo import DasFailoverLevelAdvancedRuntimeInfo as DasFailoverLevelAdvancedRuntimeInfo
from .DasFdmAvailabilityState import DasFdmAvailabilityState as DasFdmAvailabilityState
from .DasFdmHostState import DasFdmHostState as DasFdmHostState
from .DasHostInfo import DasHostInfo as DasHostInfo
from .DasHostRecommendation import DasHostRecommendation as DasHostRecommendation
from .DasVmConfigInfo import DasVmConfigInfo as DasVmConfigInfo
from .DasVmConfigSpec import DasVmConfigSpec as DasVmConfigSpec
from .DasVmSettings import DasVmSettings as DasVmSettings
from .DatastoreUpdateSpec import DatastoreUpdateSpec as DatastoreUpdateSpec
from .DependencyRuleInfo import DependencyRuleInfo as DependencyRuleInfo
from .DpmConfigInfo import DpmConfigInfo as DpmConfigInfo
from .DpmHostConfigInfo import DpmHostConfigInfo as DpmHostConfigInfo
from .DpmHostConfigSpec import DpmHostConfigSpec as DpmHostConfigSpec
from .DrsConfigInfo import DrsConfigInfo as DrsConfigInfo
from .DrsFaults import DrsFaults as DrsFaults
from .DrsMigration import DrsMigration as DrsMigration
from .DrsRecommendation import DrsRecommendation as DrsRecommendation
from .DrsVmConfigInfo import DrsVmConfigInfo as DrsVmConfigInfo
from .DrsVmConfigSpec import DrsVmConfigSpec as DrsVmConfigSpec
from .EVCManager import EVCManager as EVCManager
from .EnterMaintenanceResult import EnterMaintenanceResult as EnterMaintenanceResult
from .FailoverHostAdmissionControlInfo import FailoverHostAdmissionControlInfo as FailoverHostAdmissionControlInfo
from .FailoverHostAdmissionControlPolicy import FailoverHostAdmissionControlPolicy as FailoverHostAdmissionControlPolicy
from .FailoverLevelAdmissionControlInfo import FailoverLevelAdmissionControlInfo as FailoverLevelAdmissionControlInfo
from .FailoverLevelAdmissionControlPolicy import FailoverLevelAdmissionControlPolicy as FailoverLevelAdmissionControlPolicy
from .FailoverResourcesAdmissionControlInfo import FailoverResourcesAdmissionControlInfo as FailoverResourcesAdmissionControlInfo
from .FailoverResourcesAdmissionControlPolicy import FailoverResourcesAdmissionControlPolicy as FailoverResourcesAdmissionControlPolicy
from .FaultDomainDestroySpec import FaultDomainDestroySpec as FaultDomainDestroySpec
from .FaultDomainUpdateSpec import FaultDomainUpdateSpec as FaultDomainUpdateSpec
from .FixedSizeSlotPolicy import FixedSizeSlotPolicy as FixedSizeSlotPolicy
from .FtVmHostRuleInfo import FtVmHostRuleInfo as FtVmHostRuleInfo
from .GroupInfo import GroupInfo as GroupInfo
from .GroupSpec import GroupSpec as GroupSpec
from .HostGroup import HostGroup as HostGroup
from .HostInfraUpdateHaModeAction import HostInfraUpdateHaModeAction as HostInfraUpdateHaModeAction
from .HostPowerAction import HostPowerAction as HostPowerAction
from .HostRecommendation import HostRecommendation as HostRecommendation
from .InfraUpdateHaConfigInfo import InfraUpdateHaConfigInfo as InfraUpdateHaConfigInfo
from .InitialPlacementAction import InitialPlacementAction as InitialPlacementAction
from .MigrationAction import MigrationAction as MigrationAction
from .NotAttemptedVmInfo import NotAttemptedVmInfo as NotAttemptedVmInfo
from .OrchestrationInfo import OrchestrationInfo as OrchestrationInfo
from .PerformClusterPowerActionSpec import PerformClusterPowerActionSpec as PerformClusterPowerActionSpec
from .PlacementAction import PlacementAction as PlacementAction
from .PlacementResult import PlacementResult as PlacementResult
from .PlacementSpec import PlacementSpec as PlacementSpec
from .PowerOnVmOption import PowerOnVmOption as PowerOnVmOption
from .PowerOnVmResult import PowerOnVmResult as PowerOnVmResult
from .PreemptibleVmPairInfo import PreemptibleVmPairInfo as PreemptibleVmPairInfo
from .PreemptibleVmPairSpec import PreemptibleVmPairSpec as PreemptibleVmPairSpec
from .ProactiveDrsConfigInfo import ProactiveDrsConfigInfo as ProactiveDrsConfigInfo
from .QueryVsanManagedStorageSpaceUsageSpec import QueryVsanManagedStorageSpaceUsageSpec as QueryVsanManagedStorageSpaceUsageSpec
from .Recommendation import Recommendation as Recommendation
from .ResourceUsageSummary import ResourceUsageSummary as ResourceUsageSummary
from .RuleInfo import RuleInfo as RuleInfo
from .RuleSpec import RuleSpec as RuleSpec
from .SiteFaultDomain import SiteFaultDomain as SiteFaultDomain
from .SiteFaultDomainConfig import SiteFaultDomainConfig as SiteFaultDomainConfig
from .SlotPolicy import SlotPolicy as SlotPolicy
from .StorageComplianceResult import StorageComplianceResult as StorageComplianceResult
from .StorageOperationalStatus import StorageOperationalStatus as StorageOperationalStatus
from .StoragePolicyStatus import StoragePolicyStatus as StoragePolicyStatus
from .SystemVMsConfigInfo import SystemVMsConfigInfo as SystemVMsConfigInfo
from .SystemVMsConfigSpec import SystemVMsConfigSpec as SystemVMsConfigSpec
from .TagCategoryUpdateSpec import TagCategoryUpdateSpec as TagCategoryUpdateSpec
from .UsageSummary import UsageSummary as UsageSummary
from .VSANPreferredFaultDomainInfo import VSANPreferredFaultDomainInfo as VSANPreferredFaultDomainInfo
from .VSANStretchedClusterCapability import VSANStretchedClusterCapability as VSANStretchedClusterCapability
from .VSANStretchedClusterFaultDomainConfig import VSANStretchedClusterFaultDomainConfig as VSANStretchedClusterFaultDomainConfig
from .VSANStretchedClusterHostVirtualApplianceStatus import VSANStretchedClusterHostVirtualApplianceStatus as VSANStretchedClusterHostVirtualApplianceStatus
from .VSANWitnessHostInfo import VSANWitnessHostInfo as VSANWitnessHostInfo
from .VmComponentProtectionSettings import VmComponentProtectionSettings as VmComponentProtectionSettings
from .VmGroup import VmGroup as VmGroup
from .VmHostRuleInfo import VmHostRuleInfo as VmHostRuleInfo
from .VmOrchestrationInfo import VmOrchestrationInfo as VmOrchestrationInfo
from .VmOrchestrationSpec import VmOrchestrationSpec as VmOrchestrationSpec
from .VmReadiness import VmReadiness as VmReadiness
from .VmToolsMonitoringSettings import VmToolsMonitoringSettings as VmToolsMonitoringSettings
from .VsanAttachToSrOperation import VsanAttachToSrOperation as VsanAttachToSrOperation
from .VsanBaselinePreferenceType import VsanBaselinePreferenceType as VsanBaselinePreferenceType
from .VsanCapability import VsanCapability as VsanCapability
from .VsanCapabilityStatus import VsanCapabilityStatus as VsanCapabilityStatus
from .VsanCapabilitySystem import VsanCapabilitySystem as VsanCapabilitySystem
from .VsanCapabilityType import VsanCapabilityType as VsanCapabilityType
from .VsanCapabilityType90 import VsanCapabilityType90 as VsanCapabilityType90
from .VsanClusterAdvCfgSyncHostResult import VsanClusterAdvCfgSyncHostResult as VsanClusterAdvCfgSyncHostResult
from .VsanClusterAdvCfgSyncResult import VsanClusterAdvCfgSyncResult as VsanClusterAdvCfgSyncResult
from .VsanClusterBalancePerDiskInfo import VsanClusterBalancePerDiskInfo as VsanClusterBalancePerDiskInfo
from .VsanClusterBalanceSummary import VsanClusterBalanceSummary as VsanClusterBalanceSummary
from .VsanClusterClomdLivenessResult import VsanClusterClomdLivenessResult as VsanClusterClomdLivenessResult
from .VsanClusterConfig import VsanClusterConfig as VsanClusterConfig
from .VsanClusterCreateVmHealthTestResult import VsanClusterCreateVmHealthTestResult as VsanClusterCreateVmHealthTestResult
from .VsanClusterDitEncryptionHealthSummary import VsanClusterDitEncryptionHealthSummary as VsanClusterDitEncryptionHealthSummary
from .VsanClusterEncryptionHealthSummary import VsanClusterEncryptionHealthSummary as VsanClusterEncryptionHealthSummary
from .VsanClusterFileServiceHealthSummary import VsanClusterFileServiceHealthSummary as VsanClusterFileServiceHealthSummary
from .VsanClusterGlobalDedupHealthSummary import VsanClusterGlobalDedupHealthSummary as VsanClusterGlobalDedupHealthSummary
from .VsanClusterHclInfo import VsanClusterHclInfo as VsanClusterHclInfo
from .VsanClusterHealthAction import VsanClusterHealthAction as VsanClusterHealthAction
from .VsanClusterHealthCategoryEnum import VsanClusterHealthCategoryEnum as VsanClusterHealthCategoryEnum
from .VsanClusterHealthCheckInfo import VsanClusterHealthCheckInfo as VsanClusterHealthCheckInfo
from .VsanClusterHealthConfigs import VsanClusterHealthConfigs as VsanClusterHealthConfigs
from .VsanClusterHealthExternalLink import VsanClusterHealthExternalLink as VsanClusterHealthExternalLink
from .VsanClusterHealthGroup import VsanClusterHealthGroup as VsanClusterHealthGroup
from .VsanClusterHealthLinkBase import VsanClusterHealthLinkBase as VsanClusterHealthLinkBase
from .VsanClusterHealthQuerySpec import VsanClusterHealthQuerySpec as VsanClusterHealthQuerySpec
from .VsanClusterHealthResultBase import VsanClusterHealthResultBase as VsanClusterHealthResultBase
from .VsanClusterHealthResultColumnInfo import VsanClusterHealthResultColumnInfo as VsanClusterHealthResultColumnInfo
from .VsanClusterHealthResultKeyValuePair import VsanClusterHealthResultKeyValuePair as VsanClusterHealthResultKeyValuePair
from .VsanClusterHealthResultRow import VsanClusterHealthResultRow as VsanClusterHealthResultRow
from .VsanClusterHealthResultTable import VsanClusterHealthResultTable as VsanClusterHealthResultTable
from .VsanClusterHealthResultWithRemediation import VsanClusterHealthResultWithRemediation as VsanClusterHealthResultWithRemediation
from .VsanClusterHealthSummary import VsanClusterHealthSummary as VsanClusterHealthSummary
from .VsanClusterHealthSystem import VsanClusterHealthSystem as VsanClusterHealthSystem
from .VsanClusterHealthSystemObjectsRepairResult import VsanClusterHealthSystemObjectsRepairResult as VsanClusterHealthSystemObjectsRepairResult
from .VsanClusterHealthSystemStatusResult import VsanClusterHealthSystemStatusResult as VsanClusterHealthSystemStatusResult
from .VsanClusterHealthSystemVersionResult import VsanClusterHealthSystemVersionResult as VsanClusterHealthSystemVersionResult
from .VsanClusterHealthTest import VsanClusterHealthTest as VsanClusterHealthTest
from .VsanClusterHostVmknicMapping import VsanClusterHostVmknicMapping as VsanClusterHostVmknicMapping
from .VsanClusterLimitHealthResult import VsanClusterLimitHealthResult as VsanClusterLimitHealthResult
from .VsanClusterMgmtInternalSystem import VsanClusterMgmtInternalSystem as VsanClusterMgmtInternalSystem
from .VsanClusterNetworkHealthResult import VsanClusterNetworkHealthResult as VsanClusterNetworkHealthResult
from .VsanClusterNetworkLoadTestResult import VsanClusterNetworkLoadTestResult as VsanClusterNetworkLoadTestResult
from .VsanClusterNetworkPartitionInfo import VsanClusterNetworkPartitionInfo as VsanClusterNetworkPartitionInfo
from .VsanClusterNetworkPerfTaskSpec import VsanClusterNetworkPerfTaskSpec as VsanClusterNetworkPerfTaskSpec
from .VsanClusterPowerSystem import VsanClusterPowerSystem as VsanClusterPowerSystem
from .VsanClusterProactiveTestResult import VsanClusterProactiveTestResult as VsanClusterProactiveTestResult
from .VsanClusterTelemetryProxyConfig import VsanClusterTelemetryProxyConfig as VsanClusterTelemetryProxyConfig
from .VsanClusterVMsHealthOverallResult import VsanClusterVMsHealthOverallResult as VsanClusterVMsHealthOverallResult
from .VsanClusterVMsHealthSummaryResult import VsanClusterVMsHealthSummaryResult as VsanClusterVMsHealthSummaryResult
from .VsanClusterVmdkLoadTestResult import VsanClusterVmdkLoadTestResult as VsanClusterVmdkLoadTestResult
from .VsanClusterWhatifHostFailuresResult import VsanClusterWhatifHostFailuresResult as VsanClusterWhatifHostFailuresResult
from .VsanConfigGeneration import VsanConfigGeneration as VsanConfigGeneration
from .VsanDataDrivenAPIAction import VsanDataDrivenAPIAction as VsanDataDrivenAPIAction
from .VsanDatastoreType import VsanDatastoreType as VsanDatastoreType
from .VsanDiagnosticsSystem import VsanDiagnosticsSystem as VsanDiagnosticsSystem
from .VsanDiagnosticsThreshold import VsanDiagnosticsThreshold as VsanDiagnosticsThreshold
from .VsanDiskFormatConversionCheckResult import VsanDiskFormatConversionCheckResult as VsanDiskFormatConversionCheckResult
from .VsanDiskFormatConversionSpec import VsanDiskFormatConversionSpec as VsanDiskFormatConversionSpec
from .VsanDiskMappingsConfigSpec import VsanDiskMappingsConfigSpec as VsanDiskMappingsConfigSpec
from .VsanEntitySpaceUsage import VsanEntitySpaceUsage as VsanEntitySpaceUsage
from .VsanFaultDomainSpec import VsanFaultDomainSpec as VsanFaultDomainSpec
from .VsanFaultDomainsConfigSpec import VsanFaultDomainsConfigSpec as VsanFaultDomainsConfigSpec
from .VsanHealthActionBase import VsanHealthActionBase as VsanHealthActionBase
from .VsanHealthActionSteps import VsanHealthActionSteps as VsanHealthActionSteps
from .VsanHealthApiBasedAction import VsanHealthApiBasedAction as VsanHealthApiBasedAction
from .VsanHealthCmdBasedAction import VsanHealthCmdBasedAction as VsanHealthCmdBasedAction
from .VsanHealthConfirmationDialog import VsanHealthConfirmationDialog as VsanHealthConfirmationDialog
from .VsanHealthCorrelation import VsanHealthCorrelation as VsanHealthCorrelation
from .VsanHealthDataDrivenAction import VsanHealthDataDrivenAction as VsanHealthDataDrivenAction
from .VsanHealthExtMgmtPreCheckResult import VsanHealthExtMgmtPreCheckResult as VsanHealthExtMgmtPreCheckResult
from .VsanHealthTroubleshooting import VsanHealthTroubleshooting as VsanHealthTroubleshooting
from .VsanHealthTxtBasedAction import VsanHealthTxtBasedAction as VsanHealthTxtBasedAction
from .VsanHistoricalHealthQuerySpec import VsanHistoricalHealthQuerySpec as VsanHistoricalHealthQuerySpec
from .VsanHistoricalHealthTest import VsanHistoricalHealthTest as VsanHistoricalHealthTest
from .VsanHostClomdLivenessResult import VsanHostClomdLivenessResult as VsanHostClomdLivenessResult
from .VsanHostCreateVmHealthTestResult import VsanHostCreateVmHealthTestResult as VsanHostCreateVmHealthTestResult
from .VsanHostDiskMapping import VsanHostDiskMapping as VsanHostDiskMapping
from .VsanHostHealthSystemVersionResult import VsanHostHealthSystemVersionResult as VsanHostHealthSystemVersionResult
from .VsanIoInsightInstance import VsanIoInsightInstance as VsanIoInsightInstance
from .VsanIoInsightInstanceQuerySpec import VsanIoInsightInstanceQuerySpec as VsanIoInsightInstanceQuerySpec
from .VsanIoInsightInstanceState import VsanIoInsightInstanceState as VsanIoInsightInstanceState
from .VsanIoInsightManager import VsanIoInsightManager as VsanIoInsightManager
from .VsanIscsiHomeObjectSpec import VsanIscsiHomeObjectSpec as VsanIscsiHomeObjectSpec
from .VsanIscsiInitiatorGroup import VsanIscsiInitiatorGroup as VsanIscsiInitiatorGroup
from .VsanIscsiLUN import VsanIscsiLUN as VsanIscsiLUN
from .VsanIscsiLUNCommonInfo import VsanIscsiLUNCommonInfo as VsanIscsiLUNCommonInfo
from .VsanIscsiLUNRuntimeStatusType import VsanIscsiLUNRuntimeStatusType as VsanIscsiLUNRuntimeStatusType
from .VsanIscsiLUNSpec import VsanIscsiLUNSpec as VsanIscsiLUNSpec
from .VsanIscsiTarget import VsanIscsiTarget as VsanIscsiTarget
from .VsanIscsiTargetAuthSpec import VsanIscsiTargetAuthSpec as VsanIscsiTargetAuthSpec
from .VsanIscsiTargetBasicInfo import VsanIscsiTargetBasicInfo as VsanIscsiTargetBasicInfo
from .VsanIscsiTargetCommonInfo import VsanIscsiTargetCommonInfo as VsanIscsiTargetCommonInfo
from .VsanIscsiTargetServiceConfig import VsanIscsiTargetServiceConfig as VsanIscsiTargetServiceConfig
from .VsanIscsiTargetServiceDefaultConfigSpec import VsanIscsiTargetServiceDefaultConfigSpec as VsanIscsiTargetServiceDefaultConfigSpec
from .VsanIscsiTargetServiceProcessStatus import VsanIscsiTargetServiceProcessStatus as VsanIscsiTargetServiceProcessStatus
from .VsanIscsiTargetServiceSpec import VsanIscsiTargetServiceSpec as VsanIscsiTargetServiceSpec
from .VsanIscsiTargetSpec import VsanIscsiTargetSpec as VsanIscsiTargetSpec
from .VsanIscsiTargetSystem import VsanIscsiTargetSystem as VsanIscsiTargetSystem
from .VsanNetworkDiagnostics import VsanNetworkDiagnostics as VsanNetworkDiagnostics
from .VsanObjIdentityQuerySpec import VsanObjIdentityQuerySpec as VsanObjIdentityQuerySpec
from .VsanObjectExtAttrs import VsanObjectExtAttrs as VsanObjectExtAttrs
from .VsanObjectExtraAttributes import VsanObjectExtraAttributes as VsanObjectExtraAttributes
from .VsanObjectIdentity import VsanObjectIdentity as VsanObjectIdentity
from .VsanObjectIdentityAndHealth import VsanObjectIdentityAndHealth as VsanObjectIdentityAndHealth
from .VsanObjectInformation import VsanObjectInformation as VsanObjectInformation
from .VsanObjectQuerySpec import VsanObjectQuerySpec as VsanObjectQuerySpec
from .VsanObjectSpaceSummary import VsanObjectSpaceSummary as VsanObjectSpaceSummary
from .VsanObjectSystem import VsanObjectSystem as VsanObjectSystem
from .VsanPerfDiagnoseQuerySpec import VsanPerfDiagnoseQuerySpec as VsanPerfDiagnoseQuerySpec
from .VsanPerfDiagnosticException import VsanPerfDiagnosticException as VsanPerfDiagnosticException
from .VsanPerfDiagnosticQueryType import VsanPerfDiagnosticQueryType as VsanPerfDiagnosticQueryType
from .VsanPerfDiagnosticResult import VsanPerfDiagnosticResult as VsanPerfDiagnosticResult
from .VsanPerfEntityMetricCSV import VsanPerfEntityMetricCSV as VsanPerfEntityMetricCSV
from .VsanPerfEntityType import VsanPerfEntityType as VsanPerfEntityType
from .VsanPerfGraph import VsanPerfGraph as VsanPerfGraph
from .VsanPerfHotspotEntitiesMetrics import VsanPerfHotspotEntitiesMetrics as VsanPerfHotspotEntitiesMetrics
from .VsanPerfHotspotQuerySpec import VsanPerfHotspotQuerySpec as VsanPerfHotspotQuerySpec
from .VsanPerfMasterInformation import VsanPerfMasterInformation as VsanPerfMasterInformation
from .VsanPerfMemberInfo import VsanPerfMemberInfo as VsanPerfMemberInfo
from .VsanPerfMetricId import VsanPerfMetricId as VsanPerfMetricId
from .VsanPerfMetricSeriesCSV import VsanPerfMetricSeriesCSV as VsanPerfMetricSeriesCSV
from .VsanPerfNodeInformation import VsanPerfNodeInformation as VsanPerfNodeInformation
from .VsanPerfQuerySpec import VsanPerfQuerySpec as VsanPerfQuerySpec
from .VsanPerfThreshold import VsanPerfThreshold as VsanPerfThreshold
from .VsanPerfTimeRange import VsanPerfTimeRange as VsanPerfTimeRange
from .VsanPerfTimeRangeQuerySpec import VsanPerfTimeRangeQuerySpec as VsanPerfTimeRangeQuerySpec
from .VsanPerfTopEntities import VsanPerfTopEntities as VsanPerfTopEntities
from .VsanPerfTopEntity import VsanPerfTopEntity as VsanPerfTopEntity
from .VsanPerfTopQuerySpec import VsanPerfTopQuerySpec as VsanPerfTopQuerySpec
from .VsanPerformanceManager import VsanPerformanceManager as VsanPerformanceManager
from .VsanPerfsvcConfig import VsanPerfsvcConfig as VsanPerfsvcConfig
from .VsanRelayoutObjectsErrorCode import VsanRelayoutObjectsErrorCode as VsanRelayoutObjectsErrorCode
from .VsanRemoteClusterQuerySpec import VsanRemoteClusterQuerySpec as VsanRemoteClusterQuerySpec
from .VsanRemoteDatastoreSystem import VsanRemoteDatastoreSystem as VsanRemoteDatastoreSystem
from .VsanSpaceQuerySpec import VsanSpaceQuerySpec as VsanSpaceQuerySpec
from .VsanSpaceReportSystem import VsanSpaceReportSystem as VsanSpaceReportSystem
from .VsanSpaceReportingEntityType import VsanSpaceReportingEntityType as VsanSpaceReportingEntityType
from .VsanSpaceUsage import VsanSpaceUsage as VsanSpaceUsage
from .VsanSpaceUsageDetailResult import VsanSpaceUsageDetailResult as VsanSpaceUsageDetailResult
from .VsanSpaceUsageWithDatastoreType import VsanSpaceUsageWithDatastoreType as VsanSpaceUsageWithDatastoreType
from .VsanStorageWorkloadType import VsanStorageWorkloadType as VsanStorageWorkloadType
from .VsanStretchedClusterConfig import VsanStretchedClusterConfig as VsanStretchedClusterConfig
from .VsanSyncingObjectFilter import VsanSyncingObjectFilter as VsanSyncingObjectFilter
from .VsanUnicastAddressInfo import VsanUnicastAddressInfo as VsanUnicastAddressInfo
from .VsanUpgradeStatusEx import VsanUpgradeStatusEx as VsanUpgradeStatusEx
from .VsanUpgradeSystemUpgradeHistoryStoragePoolOp import VsanUpgradeSystemUpgradeHistoryStoragePoolOp as VsanUpgradeSystemUpgradeHistoryStoragePoolOp
from .VsanVcClusterConfigSystem import VsanVcClusterConfigSystem as VsanVcClusterConfigSystem
from .VsanVcClusterHealthSystem import VsanVcClusterHealthSystem as VsanVcClusterHealthSystem
from .VsanVcDiskManagementSystem import VsanVcDiskManagementSystem as VsanVcDiskManagementSystem
from .VsanVcKmipServersHealth import VsanVcKmipServersHealth as VsanVcKmipServersHealth
from .VsanVcLifecycleCheckResult import VsanVcLifecycleCheckResult as VsanVcLifecycleCheckResult
from .VsanVcLifecycleCheckSpec import VsanVcLifecycleCheckSpec as VsanVcLifecycleCheckSpec
from .VsanVcStretchedClusterSystem import VsanVcStretchedClusterSystem as VsanVcStretchedClusterSystem
from .VsanVsanClusterPcapGroup import VsanVsanClusterPcapGroup as VsanVsanClusterPcapGroup
from .VsanVsanClusterPcapResult import VsanVsanClusterPcapResult as VsanVsanClusterPcapResult
from .VsanVumSystem import VsanVumSystem as VsanVumSystem
from .VsanVumSystemConfig import VsanVumSystemConfig as VsanVumSystemConfig
from .VsanWhatifCapacity import VsanWhatifCapacity as VsanWhatifCapacity
from .VsanWitnessSpec import VsanWitnessSpec as VsanWitnessSpec



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vmodl import DynamicData

class NatService(DynamicData):
   class PortForwardSpecification(DynamicData):
      type: str
      name: str
      hostPort: int
      guestPort: int
      guestIpAddress: str

   class NameServiceSpec(DynamicData):
      dnsAutoDetect: bool
      dnsPolicy: str
      dnsRetries: int
      dnsTimeout: int
      dnsNameServer: list[str] = []
      nbdsTimeout: int
      nbnsRetries: int
      nbnsTimeout: int

   class Specification(DynamicData):
      virtualSwitch: str
      activeFtp: bool
      allowAnyOui: bool
      configPort: bool
      ipGatewayAddress: str
      udpTimeout: int
      portForward: list[PortForwardSpecification] = []
      nameService: Optional[NameServiceSpec] = None

   class Config(DynamicData):
      changeOperation: Optional[str] = None
      key: str
      spec: Specification

   key: str
   spec: Specification



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import ClassVar
from typing import Optional

from pyVmomi.VmomiSupport import Enum
from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vmodl import DynamicData

class Action(DynamicData):
   class ActionType(Enum):
      MigrationV1: ClassVar['ActionType'] = 'MigrationV1'
      VmPowerV1: ClassVar['ActionType'] = 'VmPowerV1'
      HostPowerV1: ClassVar['ActionType'] = 'HostPowerV1'
      IncreaseLimitV1: ClassVar['ActionType'] = 'IncreaseLimitV1'
      IncreaseSizeV1: ClassVar['ActionType'] = 'IncreaseSizeV1'
      IncreaseSharesV1: ClassVar['ActionType'] = 'IncreaseSharesV1'
      IncreaseReservationV1: ClassVar['ActionType'] = 'IncreaseReservationV1'
      DecreaseOthersReservationV1: ClassVar['ActionType'] = 'DecreaseOthersReservationV1'
      IncreaseClusterCapacityV1: ClassVar['ActionType'] = 'IncreaseClusterCapacityV1'
      DecreaseMigrationThresholdV1: ClassVar['ActionType'] = 'DecreaseMigrationThresholdV1'
      HostMaintenanceV1: ClassVar['ActionType'] = 'HostMaintenanceV1'
      StorageMigrationV1: ClassVar['ActionType'] = 'StorageMigrationV1'
      StoragePlacementV1: ClassVar['ActionType'] = 'StoragePlacementV1'
      PlacementV1: ClassVar['ActionType'] = 'PlacementV1'
      HostInfraUpdateHaV1: ClassVar['ActionType'] = 'HostInfraUpdateHaV1'

   type: str
   target: Optional[ManagedObject] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import NoReturn
from typing import Optional

from pyVmomi.VmomiSupport import ManagedObject

from pyVmomi.vim import Datastore
from pyVmomi.vim import Network

from pyVmomi.vmodl import DynamicData

class EsxAgentHostManager(ManagedObject):
   class ConfigInfo(DynamicData):
      agentVmDatastore: Optional[Datastore] = None
      agentVmNetwork: Optional[Network] = None

   @property
   def configInfo(self) -> ConfigInfo: ...

   def UpdateConfig(self, configInfo: ConfigInfo) -> NoReturn: ...



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import ManagedEntity

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.action import Action

from pyVmomi.vim.alarm import AlarmAction

class AlarmTriggeringAction(AlarmAction):
   class TransitionSpec(DynamicData):
      startState: ManagedEntity.Status
      finalState: ManagedEntity.Status
      repeats: bool

   action: Action
   transitionSpecs: list[TransitionSpec] = []
   green2yellow: bool
   yellow2red: bool
   red2yellow: bool
   yellow2green: bool



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HostSystem

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.cluster import VsanStretchedClusterConfig

from pyVmomi.vim.vsan.host import AddStoragePoolDiskSpec
from pyVmomi.vim.vsan.host import DiskMapping

class VsanVcStretchedClusterConfigSpec(DynamicData):
   witnessHost: HostSystem
   clusters: list[VsanStretchedClusterConfig] = []
   witnessDiskMappings: list[DiskMapping] = []
   witnessStoragePoolSpecs: list[AddStoragePoolDiskSpec] = []



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from .CertificateNotTrustedFault import CertificateNotTrustedFault as CertificateNotTrustedFault
from .DisabledClusterFault import DisabledClusterFault as DisabledClusterFault
from .EamAppFault import EamAppFault as EamAppFault
from .EamFault import EamFault as EamFault
from .EamIOFault import EamIOFault as EamIOFault
from .EamRuntimeFault import EamRuntimeFault as EamRuntimeFault
from .EamServiceNotInitialized import EamServiceNotInitialized as EamServiceNotInitialized
from .EamSystemFault import EamSystemFault as EamSystemFault
from .InvalidAgencyScope import InvalidAgencyScope as InvalidAgencyScope
from .InvalidAgentConfiguration import InvalidAgentConfiguration as InvalidAgentConfiguration
from .InvalidLogin import InvalidLogin as InvalidLogin
from .InvalidState import InvalidState as InvalidState
from .InvalidUrl import InvalidUrl as InvalidUrl
from .InvalidVibPackage import InvalidVibPackage as InvalidVibPackage
from .NoConnectionToVCenter import NoConnectionToVCenter as NoConnectionToVCenter
from .NotAuthorized import NotAuthorized as NotAuthorized



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.VmomiSupport import long

from pyVmomi.vmodl import DynamicData

from pyVmomi.vim.host import VsanVmdkLoadTestSpec

class VsanVmdkLoadTestResult(DynamicData):
   success: bool
   faultMessage: Optional[str] = None
   spec: VsanVmdkLoadTestSpec
   actualDurationSec: Optional[int] = None
   totalBytes: Optional[long] = None
   iops: Optional[long] = None
   tputBps: Optional[long] = None
   avgLatencyUs: Optional[long] = None
   maxLatencyUs: Optional[long] = None
   numIoAboveLatencyThreshold: Optional[long] = None



# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from typing import Optional

from pyVmomi.vim import HistoryCollector
from pyVmomi.vim import TaskInfo

class TaskHistoryCollector(HistoryCollector):
   @property
   def latestPage(self) -> list[TaskInfo]: ...

   def ReadNext(self, maxCount: int) -> list[TaskInfo]: ...
   def ReadPrev(self, maxCount: int) -> list[TaskInfo]: ...
